# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class PreviousMedalists(BaseModel):
    previous_medalists: Optional[
        List[Optional["PreviousMedalistsPreviousMedalists"]]
    ] = Field(alias="previousMedalists")


class PreviousMedalistsPreviousMedalists(BaseModel):
    id: Optional[int]
    competitor_id__w_a: Optional[int] = Field(alias="competitorId_WA")
    medal_table_id: Optional[int] = Field(alias="medalTableId")
    type_id: Optional[int] = Field(alias="typeId")
    result_mark: Optional[str] = Field(alias="resultMark")
    first_name: Optional[str] = Field(alias="firstName")
    last_name: Optional[str] = Field(alias="lastName")
    name: Optional[str]
    country_code: Optional[str] = Field(alias="countryCode")
    country_name: Optional[str] = Field(alias="countryName")
    url_slug: Optional[str] = Field(alias="urlSlug")
    country_url_slug: Optional[str] = Field(alias="countryUrlSlug")


PreviousMedalists.update_forward_refs()
PreviousMedalistsPreviousMedalists.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetSingleCompetitorHonourSummary(BaseModel):
    get_single_competitor_honour_summary: Optional[
        List[
            Optional["GetSingleCompetitorHonourSummaryGetSingleCompetitorHonourSummary"]
        ]
    ] = Field(alias="getSingleCompetitorHonourSummary")


class GetSingleCompetitorHonourSummaryGetSingleCompetitorHonourSummary(BaseModel):
    count: Optional[int]
    honour: Optional[str]


GetSingleCompetitorHonourSummary.update_forward_refs()
GetSingleCompetitorHonourSummaryGetSingleCompetitorHonourSummary.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetFlashInterviews(BaseModel):
    get_flash_interviews: Optional[
        List[Optional[List[Optional["GetFlashInterviewsGetFlashInterviews"]]]]
    ] = Field(alias="getFlashInterviews")


class GetFlashInterviewsGetFlashInterviews(BaseModel):
    discipline_name: Optional[str] = Field(alias="disciplineName")
    discipline_sex_name: Optional[str] = Field(alias="disciplineSexName")
    unit_type_name: Optional[str] = Field(alias="unitTypeName")
    unit_name: Optional[str] = Field(alias="unitName")
    phase_name: Optional[str] = Field(alias="phaseName")
    phase_id: Optional[int] = Field(alias="phaseId")
    unit_id: Optional[int] = Field(alias="unitId")
    interviews: Optional[
        List[Optional["GetFlashInterviewsGetFlashInterviewsInterviews"]]
    ]


class GetFlashInterviewsGetFlashInterviewsInterviews(BaseModel):
    id: Optional[int]
    phase_id: Optional[int] = Field(alias="phaseId")
    phase_date: Optional[Any] = Field(alias="phaseDate")
    phase_name: Optional[str] = Field(alias="phaseName")
    unit_id: Optional[int] = Field(alias="unitId")
    unit_code: Optional[int] = Field(alias="unitCode")
    unit_type_name: Optional[str] = Field(alias="unitTypeName")
    unit_name: Optional[str] = Field(alias="unitName")
    title: Optional[str]
    body: Optional[str]
    competitor_id: Optional[int] = Field(alias="competitorId")
    competitor_team_name: Optional[str] = Field(alias="competitorTeamName")
    competitor_forename: Optional[str] = Field(alias="competitorForename")
    competitor_surname: Optional[str] = Field(alias="competitorSurname")
    competitor_country_code: Optional[str] = Field(alias="competitorCountryCode")
    competitor_sex: Optional[str] = Field(alias="competitorSex")
    competitor_type: Optional[str] = Field(alias="competitorType")
    updated_on: Optional[Any] = Field(alias="updatedOn")
    event_id: Optional[int] = Field(alias="eventId")
    discipline_code: Optional[str] = Field(alias="disciplineCode")
    discipline_name: Optional[str] = Field(alias="disciplineName")
    discipline_sex_name: Optional[str] = Field(alias="disciplineSexName")
    flash_interview_order: Optional[int] = Field(alias="flashInterviewOrder")
    flash_interview_date: Optional[Any] = Field(alias="flashInterviewDate")
    flash_interview_has_time: Optional[bool] = Field(alias="flashInterviewHasTime")
    event_store_id: Optional[str] = Field(alias="eventStoreId")
    is_approved: Optional[bool] = Field(alias="isApproved")


GetFlashInterviews.update_forward_refs()
GetFlashInterviewsGetFlashInterviews.update_forward_refs()
GetFlashInterviewsGetFlashInterviewsInterviews.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetSingleCompetitorMajorChampionships(BaseModel):
    get_single_competitor_major_championships: Optional[
        "GetSingleCompetitorMajorChampionshipsGetSingleCompetitorMajorChampionships"
    ] = Field(alias="getSingleCompetitorMajorChampionships")


class GetSingleCompetitorMajorChampionshipsGetSingleCompetitorMajorChampionships(
    BaseModel
):
    parameters: Optional[
        "GetSingleCompetitorMajorChampionshipsGetSingleCompetitorMajorChampionshipsParameters"
    ]
    results: Optional[
        List[
            Optional[
                "GetSingleCompetitorMajorChampionshipsGetSingleCompetitorMajorChampionshipsResults"
            ]
        ]
    ]


class GetSingleCompetitorMajorChampionshipsGetSingleCompetitorMajorChampionshipsParameters(
    BaseModel
):
    major_championships_by_category: Optional[bool] = Field(
        alias="majorChampionshipsByCategory"
    )


class GetSingleCompetitorMajorChampionshipsGetSingleCompetitorMajorChampionshipsResults(
    BaseModel
):
    category: Optional[str]
    results: Optional[
        List[
            Optional[
                "GetSingleCompetitorMajorChampionshipsGetSingleCompetitorMajorChampionshipsResultsResults"
            ]
        ]
    ]


class GetSingleCompetitorMajorChampionshipsGetSingleCompetitorMajorChampionshipsResultsResults(
    BaseModel
):
    id: Optional[int]
    discipline: Optional[str]
    competition: Optional[str]
    venue: Optional[str]
    race: Optional[str]
    place: Optional[str]
    result: Optional[str]
    with_wind: Optional[bool] = Field(alias="withWind")
    wind: Optional[str]
    with_drop: Optional[bool] = Field(alias="withDrop")
    drop: Optional[str]
    date: Optional[str]


GetSingleCompetitorMajorChampionships.update_forward_refs()
GetSingleCompetitorMajorChampionshipsGetSingleCompetitorMajorChampionships.update_forward_refs()
GetSingleCompetitorMajorChampionshipsGetSingleCompetitorMajorChampionshipsParameters.update_forward_refs()
GetSingleCompetitorMajorChampionshipsGetSingleCompetitorMajorChampionshipsResults.update_forward_refs()
GetSingleCompetitorMajorChampionshipsGetSingleCompetitorMajorChampionshipsResultsResults.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class VerifyHCaptchaToken(BaseModel):
    verify_h_captcha_token: Optional["VerifyHCaptchaTokenVerifyHCaptchaToken"] = Field(
        alias="verifyHCaptchaToken"
    )


class VerifyHCaptchaTokenVerifyHCaptchaToken(BaseModel):
    is_success: Optional[bool] = Field(alias="isSuccess")
    error_codes: Optional[List[Optional[str]]] = Field(alias="errorCodes")
    hostname: Optional[str]


VerifyHCaptchaToken.update_forward_refs()
VerifyHCaptchaTokenVerifyHCaptchaToken.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:50
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class SearchCompetitors(BaseModel):
    search_competitors: Optional[
        List[Optional["SearchCompetitorsSearchCompetitors"]]
    ] = Field(alias="searchCompetitors")


class SearchCompetitorsSearchCompetitors(BaseModel):
    aa_athlete_id: Optional[str] = Field(alias="aaAthleteId")
    family_name: Optional[str] = Field(alias="familyName")
    given_name: Optional[str] = Field(alias="givenName")
    birth_date: Optional[str] = Field(alias="birthDate")
    disciplines: Optional[str]
    iaaf_id: Optional[int] = Field(alias="iaafId")
    gender: Optional[str]
    country: Optional[str]
    url_slug: Optional[str] = Field(alias="urlSlug")


SearchCompetitors.update_forward_refs()
SearchCompetitorsSearchCompetitors.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class AirQualityDevices(BaseModel):
    air_quality_devices: Optional[
        List[Optional["AirQualityDevicesAirQualityDevices"]]
    ] = Field(alias="airQualityDevices")


class AirQualityDevicesAirQualityDevices(BaseModel):
    serial_number: Optional[str]
    tag: Optional[str]
    status: Optional[int]
    last_connection_ts: Optional[Any]
    location: Optional["AirQualityDevicesAirQualityDevicesLocation"]


class AirQualityDevicesAirQualityDevicesLocation(BaseModel):
    latitude: Optional[str]
    longitude: Optional[str]


AirQualityDevices.update_forward_refs()
AirQualityDevicesAirQualityDevices.update_forward_refs()
AirQualityDevicesAirQualityDevicesLocation.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:50
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetRecentResults(BaseModel):
    get_recent_results: Optional["GetRecentResultsGetRecentResults"] = Field(
        alias="getRecentResults"
    )


class GetRecentResultsGetRecentResults(BaseModel):
    module_title: Optional[str] = Field(alias="moduleTitle")
    module_subtitle: Optional[str] = Field(alias="moduleSubtitle")
    results: Optional[List[Optional["GetRecentResultsGetRecentResultsResults"]]]


class GetRecentResultsGetRecentResultsResults(BaseModel):
    id: Optional[int]
    iaaf_id: Optional[int] = Field(alias="iaafId")
    name: Optional[str]
    venue: Optional[str]
    start_date: Optional[Any] = Field(alias="startDate")
    end_date: Optional[Any] = Field(alias="endDate")
    event: Optional["GetRecentResultsGetRecentResultsResultsEvent"]


class GetRecentResultsGetRecentResultsResultsEvent(BaseModel):
    id: Optional[int]
    updated_on: Optional[Any] = Field(alias="updatedOn")
    name: Optional[str]
    start_date: Optional[Any] = Field(alias="startDate")
    end_date: Optional[Any] = Field(alias="endDate")
    hash: Optional[str]
    venue: Optional[str]
    country_code: Optional[str] = Field(alias="countryCode")
    country_name: Optional[str] = Field(alias="countryName")
    area_code: Optional[str] = Field(alias="areaCode")
    area_name: Optional[str] = Field(alias="areaName")
    age_code: Optional[str] = Field(alias="ageCode")
    indoor_outdoor: Optional[str] = Field(alias="indoorOutdoor")
    category_code: Optional[str] = Field(alias="categoryCode")
    category_name: Optional[str] = Field(alias="categoryName")
    category_order: Optional[int] = Field(alias="categoryOrder")
    sub_category_code: Optional[str] = Field(alias="subCategoryCode")
    sub_category_name: Optional[str] = Field(alias="subCategoryName")
    show_web_live_banner: Optional[bool] = Field(alias="showWebLiveBanner")
    sub_category_order: Optional[int] = Field(alias="subCategoryOrder")
    class_code: Optional[str] = Field(alias="classCode")
    class_order: Optional[int] = Field(alias="classOrder")
    is_published: Optional[bool] = Field(alias="isPublished")
    has_comp_doc_results: Optional[bool] = Field(alias="hasCompDocResults")
    name_url_slug: Optional[str] = Field(alias="nameUrlSlug")
    start_date_year: Optional[int] = Field(alias="startDateYear")
    circuits: Optional[
        List[Optional["GetRecentResultsGetRecentResultsResultsEventCircuits"]]
    ]
    area_name_url_slug: Optional[str] = Field(alias="areaNameUrlSlug")
    category_name_url_slug: Optional[str] = Field(alias="categoryNameUrlSlug")
    sub_category_name_url_slug: Optional[str] = Field(alias="subCategoryNameUrlSlug")
    discipline_codes: Optional[List[Optional[str]]] = Field(alias="disciplineCodes")
    event_id__w_a: Optional[int] = Field(alias="eventId_WA")
    has_timetable: Optional[bool] = Field(alias="hasTimetable")
    page: Optional["GetRecentResultsGetRecentResultsResultsEventPage"]
    event_start_date_time: Optional[Any] = Field(alias="eventStartDateTime")
    event_end_date_time: Optional[Any] = Field(alias="eventEndDateTime")
    venue_timezone: Optional[str] = Field(alias="venueTimezone")


class GetRecentResultsGetRecentResultsResultsEventCircuits(BaseModel):
    updated_on: Optional[Any] = Field(alias="UpdatedOn")
    hash: Optional[str]
    circuit_code: Optional[str] = Field(alias="circuitCode")
    circuit_type_code: Optional[str] = Field(alias="circuitTypeCode")
    circuit_name: Optional[str] = Field(alias="circuitName")
    season: Optional[int]
    circuit_order: Optional[int] = Field(alias="circuitOrder")
    circuit_type_name: Optional[str] = Field(alias="circuitTypeName")


class GetRecentResultsGetRecentResultsResultsEventPage(BaseModel):
    id: Optional[str]
    type_id: Optional[str] = Field(alias="typeId")
    language: Optional[str]
    title: Optional[str]
    competition_id: Optional[str] = Field(alias="competitionId")
    event_id: Optional[int] = Field(alias="eventId")
    site_id: Optional[str] = Field(alias="siteId")
    seo_description: Optional[str] = Field(alias="seoDescription")
    slug: Optional[str]
    published_by_id: Optional[str] = Field(alias="publishedById")
    published_by_name: Optional[str] = Field(alias="publishedByName")
    published: Optional[Any]
    gated_content: Optional[bool] = Field(alias="gatedContent")
    campaign_id: Optional[str] = Field(alias="campaignId")


GetRecentResults.update_forward_refs()
GetRecentResultsGetRecentResults.update_forward_refs()
GetRecentResultsGetRecentResultsResults.update_forward_refs()
GetRecentResultsGetRecentResultsResultsEvent.update_forward_refs()
GetRecentResultsGetRecentResultsResultsEventCircuits.update_forward_refs()
GetRecentResultsGetRecentResultsResultsEventPage.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetAthleteRepresentativeAthleteSearch(BaseModel):
    get_athlete_representative_athlete_search: Optional[
        "GetAthleteRepresentativeAthleteSearchGetAthleteRepresentativeAthleteSearch"
    ] = Field(alias="getAthleteRepresentativeAthleteSearch")


class GetAthleteRepresentativeAthleteSearchGetAthleteRepresentativeAthleteSearch(
    BaseModel
):
    countries: Optional[
        List[
            Optional[
                "GetAthleteRepresentativeAthleteSearchGetAthleteRepresentativeAthleteSearchCountries"
            ]
        ]
    ]
    athletes: Optional[
        List[
            Optional[
                "GetAthleteRepresentativeAthleteSearchGetAthleteRepresentativeAthleteSearchAthletes"
            ]
        ]
    ]


class GetAthleteRepresentativeAthleteSearchGetAthleteRepresentativeAthleteSearchCountries(
    BaseModel
):
    country: Optional[str]
    country_code: Optional[str] = Field(alias="countryCode")


class GetAthleteRepresentativeAthleteSearchGetAthleteRepresentativeAthleteSearchAthletes(
    BaseModel
):
    group: Optional[str]
    children: Optional[
        List[
            Optional[
                "GetAthleteRepresentativeAthleteSearchGetAthleteRepresentativeAthleteSearchAthletesChildren"
            ]
        ]
    ]


class GetAthleteRepresentativeAthleteSearchGetAthleteRepresentativeAthleteSearchAthletesChildren(
    BaseModel
):
    athlete_representative_id: Optional[int] = Field(alias="athleteRepresentativeId")
    country_code: Optional[str] = Field(alias="countryCode")
    first_name: Optional[str] = Field(alias="firstName")
    birthdate: Optional[str]
    athlete_id: Optional[int] = Field(alias="athleteId")
    last_name: Optional[str] = Field(alias="lastName")
    country: Optional[str]
    gender: Optional[str]


GetAthleteRepresentativeAthleteSearch.update_forward_refs()
GetAthleteRepresentativeAthleteSearchGetAthleteRepresentativeAthleteSearch.update_forward_refs()
GetAthleteRepresentativeAthleteSearchGetAthleteRepresentativeAthleteSearchCountries.update_forward_refs()
GetAthleteRepresentativeAthleteSearchGetAthleteRepresentativeAthleteSearchAthletes.update_forward_refs()
GetAthleteRepresentativeAthleteSearchGetAthleteRepresentativeAthleteSearchAthletesChildren.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetWorldRanking(BaseModel):
    get_world_ranking: Optional[
        List[Optional["GetWorldRankingGetWorldRanking"]]
    ] = Field(alias="getWorldRanking")


class GetWorldRankingGetWorldRanking(BaseModel):
    id: Optional[int]
    place: Optional[int]
    world_place: Optional[int] = Field(alias="worldPlace")
    athlete: Optional[str]
    athlete_url_slug: Optional[str] = Field(alias="athleteUrlSlug")
    birth_date: Optional[str] = Field(alias="birthDate")
    nationality: Optional[str]
    ranking_score: Optional[int] = Field(alias="rankingScore")
    disciplines: Optional[str]
    country_place: Optional[int] = Field(alias="countryPlace")
    previous_id: Optional[int] = Field(alias="previousId")
    previous_place: Optional[int] = Field(alias="previousPlace")
    previous_ranking_score: Optional[int] = Field(alias="previousRankingScore")


GetWorldRanking.update_forward_refs()
GetWorldRankingGetWorldRanking.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetSingleCompetitorSeasonBests(BaseModel):
    get_single_competitor_season_bests: Optional[
        "GetSingleCompetitorSeasonBestsGetSingleCompetitorSeasonBests"
    ] = Field(alias="getSingleCompetitorSeasonBests")


class GetSingleCompetitorSeasonBestsGetSingleCompetitorSeasonBests(BaseModel):
    parameters: Optional[
        "GetSingleCompetitorSeasonBestsGetSingleCompetitorSeasonBestsParameters"
    ]
    active_seasons: Optional[List[Optional[str]]] = Field(alias="activeSeasons")
    with_wind: Optional[bool] = Field(alias="withWind")
    with_records: Optional[bool] = Field(alias="withRecords")
    results: Optional[
        List[
            Optional[
                "GetSingleCompetitorSeasonBestsGetSingleCompetitorSeasonBestsResults"
            ]
        ]
    ]


class GetSingleCompetitorSeasonBestsGetSingleCompetitorSeasonBestsParameters(BaseModel):
    seasons_bests_season: Optional[int] = Field(alias="seasonsBestsSeason")


class GetSingleCompetitorSeasonBestsGetSingleCompetitorSeasonBestsResults(BaseModel):
    indoor: Optional[bool]
    discipline_code: Optional[str] = Field(alias="disciplineCode")
    discipline_name_url_slug: Optional[str] = Field(alias="disciplineNameUrlSlug")
    type_name_url_slug: Optional[str] = Field(alias="typeNameUrlSlug")
    discipline: Optional[str]
    link_to_list: Optional[bool] = Field(alias="linkToList")
    mark: Optional[str]
    combined_performances: Optional[str] = Field(alias="combinedPerformances")
    wind: Optional[str]
    not_legal: Optional[bool] = Field(alias="notLegal")
    venue: Optional[str]
    date: Optional[str]
    list_position: Optional[str] = Field(alias="listPosition")
    result_score: Optional[int] = Field(alias="resultScore")
    records: Optional[List[Optional[str]]]


GetSingleCompetitorSeasonBests.update_forward_refs()
GetSingleCompetitorSeasonBestsGetSingleCompetitorSeasonBests.update_forward_refs()
GetSingleCompetitorSeasonBestsGetSingleCompetitorSeasonBestsParameters.update_forward_refs()
GetSingleCompetitorSeasonBestsGetSingleCompetitorSeasonBestsResults.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:50
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetVideoById(BaseModel):
    get_video_by_id: Optional["GetVideoByIdGetVideoById"] = Field(alias="getVideoById")


class GetVideoByIdGetVideoById(BaseModel):
    id: Optional[str]
    content_id: Optional[str] = Field(alias="contentId")
    published_by_id: Optional[str] = Field(alias="publishedById")
    published_by_name: Optional[str] = Field(alias="publishedByName")
    published: Optional[str]
    language: Optional[str]
    gated_content: Optional[bool] = Field(alias="gatedContent")
    campaign_id: Optional[str] = Field(alias="campaignId")
    tags: Optional[List[Optional[str]]]
    title: Optional[str]
    thumbnail_id: Optional[str] = Field(alias="thumbnailId")
    thumbnail_edited: Optional[str] = Field(alias="thumbnailEdited")
    video_id: Optional[str] = Field(alias="videoId")
    player_id: Optional[str] = Field(alias="playerId")
    tag_id: Optional[str] = Field(alias="tagId")
    stand_first: Optional[str] = Field(alias="standFirst")


GetVideoById.update_forward_refs()
GetVideoByIdGetVideoById.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetEvent(BaseModel):
    get_event: Optional["GetEventGetEvent"] = Field(alias="getEvent")


class GetEventGetEvent(BaseModel):
    id: Optional[str]
    media_ids: Optional[List[Optional[int]]] = Field(alias="mediaIds")
    related_media: Optional[List[Optional["GetEventGetEventRelatedMedia"]]] = Field(
        alias="relatedMedia"
    )
    timezone: Optional[str]
    updated_on: Optional[Any] = Field(alias="updatedOn")
    hash: Optional[str]
    name: Optional[str]
    start_date: Optional[Any] = Field(alias="startDate")
    end_date: Optional[Any] = Field(alias="endDate")
    venue: Optional[str]
    country_code: Optional[str] = Field(alias="countryCode")
    country_name: Optional[str] = Field(alias="countryName")
    area_code: Optional[str] = Field(alias="areaCode")
    area_name: Optional[str] = Field(alias="areaName")
    age_code: Optional[str] = Field(alias="ageCode")
    indoor_outdoor: Optional[str] = Field(alias="indoorOutdoor")
    category_code: Optional[str] = Field(alias="categoryCode")
    category_name: Optional[str] = Field(alias="categoryName")
    category_order: Optional[int] = Field(alias="categoryOrder")
    sub_category_code: Optional[str] = Field(alias="subCategoryCode")
    sub_category_name: Optional[str] = Field(alias="subCategoryName")
    sub_category_order: Optional[int] = Field(alias="subCategoryOrder")
    show_web_live_banner: Optional[bool] = Field(alias="showWebLiveBanner")
    event_id__w_a: Optional[int] = Field(alias="eventId_WA")
    class_code: Optional[str] = Field(alias="classCode")
    class_name: Optional[str] = Field(alias="className")
    class_order: Optional[int] = Field(alias="classOrder")
    is_published: Optional[bool] = Field(alias="isPublished")
    has_comp_doc_results: Optional[bool] = Field(alias="hasCompDocResults")
    name_url_slug: Optional[str] = Field(alias="nameUrlSlug")
    start_date_year: Optional[int] = Field(alias="startDateYear")
    circuits: Optional[List[Optional["GetEventGetEventCircuits"]]]
    area_name_url_slug: Optional[str] = Field(alias="areaNameUrlSlug")
    category_name_url_slug: Optional[str] = Field(alias="categoryNameUrlSlug")
    sub_category_name_url_slug: Optional[str] = Field(alias="subCategoryNameUrlSlug")
    discipline_codes: Optional[List[Optional[str]]] = Field(alias="disciplineCodes")


class GetEventGetEventRelatedMedia(BaseModel):
    id: Optional[str]
    media_type: Optional[str] = Field(alias="mediaType")
    title: Optional[str]
    copyright: Optional[str]
    file_name: Optional[str] = Field(alias="fileName")
    related_athletes: Optional[List[Optional[int]]] = Field(alias="relatedAthletes")
    related_disciplines: Optional[List[Optional[str]]] = Field(
        alias="relatedDisciplines"
    )
    related_competitions: Optional[List[Optional[str]]] = Field(
        alias="relatedCompetitions"
    )
    related_events: Optional[List[Optional[int]]] = Field(alias="relatedEvents")
    is_deleted: Optional[bool] = Field(alias="isDeleted")
    live_from: Optional[Any] = Field(alias="liveFrom")


class GetEventGetEventCircuits(BaseModel):
    updated_on: Optional[Any] = Field(alias="UpdatedOn")
    hash: Optional[str]
    circuit_code: Optional[str] = Field(alias="circuitCode")
    circuit_type_code: Optional[str] = Field(alias="circuitTypeCode")
    circuit_name: Optional[str] = Field(alias="circuitName")
    season: Optional[int]
    circuit_order: Optional[int] = Field(alias="circuitOrder")
    circuit_type_name: Optional[str] = Field(alias="circuitTypeName")


GetEvent.update_forward_refs()
GetEventGetEvent.update_forward_refs()
GetEventGetEventRelatedMedia.update_forward_refs()
GetEventGetEventCircuits.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:50
# Source: graphql/queries.graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class GetVideosTotalNumber(BaseModel):
    get_videos_total_number: Optional[
        "GetVideosTotalNumberGetVideosTotalNumber"
    ] = Field(alias="getVideosTotalNumber")


class GetVideosTotalNumberGetVideosTotalNumber(BaseModel):
    total: Optional[str]


GetVideosTotalNumber.update_forward_refs()
GetVideosTotalNumberGetVideosTotalNumber.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:50
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetLiveBlogPosts(BaseModel):
    get_live_blog_posts: Optional[
        List[Optional["GetLiveBlogPostsGetLiveBlogPosts"]]
    ] = Field(alias="getLiveBlogPosts")


class GetLiveBlogPostsGetLiveBlogPosts(BaseModel):
    id: Optional[str]
    parent_id: Optional[str] = Field(alias="parentId")
    post_id: Optional[str] = Field(alias="postId")
    language: Optional[str]
    title: Optional[str]
    image_id: Optional[str] = Field(alias="imageId")
    image_edited: Optional[str] = Field(alias="imageEdited")
    text: Optional[str]
    date_time: Optional[Any] = Field(alias="dateTime")


GetLiveBlogPosts.update_forward_refs()
GetLiveBlogPostsGetLiveBlogPosts.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:50
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetArticleLocations(BaseModel):
    get_article_locations: Optional[
        List[Optional["GetArticleLocationsGetArticleLocations"]]
    ] = Field(alias="getArticleLocations")


class GetArticleLocationsGetArticleLocations(BaseModel):
    id: Optional[str]
    name: Optional[str]
    latitude: Optional[float]
    longitude: Optional[float]


GetArticleLocations.update_forward_refs()
GetArticleLocationsGetArticleLocations.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetMinisiteCalendarEvents(BaseModel):
    get_minisite_calendar_events: Optional[
        "GetMinisiteCalendarEventsGetMinisiteCalendarEvents"
    ] = Field(alias="getMinisiteCalendarEvents")


class GetMinisiteCalendarEventsGetMinisiteCalendarEvents(BaseModel):
    hits: Optional[int]
    default_offset: Optional[int] = Field(alias="defaultOffset")
    pagination_page: Optional[int] = Field(alias="paginationPage")
    parameters: Optional["GetMinisiteCalendarEventsGetMinisiteCalendarEventsParameters"]
    results: Optional[
        List[Optional["GetMinisiteCalendarEventsGetMinisiteCalendarEventsResults"]]
    ]
    options: Optional["GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptions"]


class GetMinisiteCalendarEventsGetMinisiteCalendarEventsParameters(BaseModel):
    start_date: Optional[str] = Field(alias="startDate")
    end_date: Optional[str] = Field(alias="endDate")
    query: Optional[str]
    region_type: Optional[str] = Field(alias="regionType")
    region_id: Optional[int] = Field(alias="regionId")
    discipline_id: Optional[int] = Field(alias="disciplineId")
    ranking_category_id: Optional[int] = Field(alias="rankingCategoryId")
    permit_level_id: Optional[int] = Field(alias="permitLevelId")
    competition_group_id: Optional[int] = Field(alias="competitionGroupId")
    competition_subgroup_id: Optional[int] = Field(alias="competitionSubgroupId")
    limit: Optional[int]
    offset: Optional[int]
    show_options_with_no_hits: Optional[bool] = Field(alias="showOptionsWithNoHits")
    hide_competitions_with_no_results: Optional[bool] = Field(
        alias="hideCompetitionsWithNoResults"
    )
    season: Optional[str]


class GetMinisiteCalendarEventsGetMinisiteCalendarEventsResults(BaseModel):
    id: Optional[int]
    iaaf_id: Optional[int] = Field(alias="iaafId")
    has_results: Optional[bool] = Field(alias="hasResults")
    has_api_results: Optional[bool] = Field(alias="hasApiResults")
    has_startlist: Optional[bool] = Field(alias="hasStartlist")
    name: Optional[str]
    venue: Optional[str]
    area: Optional[str]
    country: Optional[str]
    ranking_category: Optional[str] = Field(alias="rankingCategory")
    disciplines: Optional[str]
    competition_group: Optional[str] = Field(alias="competitionGroup")
    competition_subgroup: Optional[str] = Field(alias="competitionSubgroup")
    start_date: Optional[str] = Field(alias="startDate")
    end_date: Optional[str] = Field(alias="endDate")
    date_range: Optional[str] = Field(alias="dateRange")
    season: Optional[str]
    was_url: Optional[str] = Field(alias="wasUrl")
    has_competition_information: Optional[bool] = Field(
        alias="hasCompetitionInformation"
    )
    undetermined_competition_period: Optional[
        "GetMinisiteCalendarEventsGetMinisiteCalendarEventsResultsUndeterminedCompetitionPeriod"
    ] = Field(alias="undeterminedCompetitionPeriod")


class GetMinisiteCalendarEventsGetMinisiteCalendarEventsResultsUndeterminedCompetitionPeriod(
    BaseModel
):
    status: Optional[str]
    label: Optional[str]
    remark: Optional[str]


class GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptions(BaseModel):
    regions: Optional[
        "GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsRegions"
    ]
    seasons: Optional[
        List[
            Optional["GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsSeasons"]
        ]
    ]
    disciplines: Optional[
        List[
            Optional[
                "GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsDisciplines"
            ]
        ]
    ]
    ranking_categories: Optional[
        List[
            Optional[
                "GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsRankingCategories"
            ]
        ]
    ] = Field(alias="rankingCategories")
    permit_levels: Optional[
        List[
            Optional[
                "GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsPermitLevels"
            ]
        ]
    ] = Field(alias="permitLevels")
    competition_groups: Optional[
        List[
            Optional[
                "GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsCompetitionGroups"
            ]
        ]
    ] = Field(alias="competitionGroups")
    competition_subgroups: Optional[
        List[
            Optional[
                "GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsCompetitionSubgroups"
            ]
        ]
    ] = Field(alias="competitionSubgroups")


class GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsRegions(BaseModel):
    world: Optional[
        List[
            Optional[
                "GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsRegionsWorld"
            ]
        ]
    ]
    area: Optional[
        List[
            Optional[
                "GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsRegionsArea"
            ]
        ]
    ]
    country: Optional[
        List[
            Optional[
                "GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsRegionsCountry"
            ]
        ]
    ]


class GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsRegionsWorld(BaseModel):
    id: Optional[int]
    name: Optional[str]
    count: Optional[int]


class GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsRegionsArea(BaseModel):
    id: Optional[int]
    name: Optional[str]
    count: Optional[int]


class GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsRegionsCountry(
    BaseModel
):
    id: Optional[int]
    name: Optional[str]
    count: Optional[int]


class GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsSeasons(BaseModel):
    id: Optional[str]
    name: Optional[str]


class GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsDisciplines(BaseModel):
    id: Optional[int]
    name: Optional[str]
    count: Optional[int]


class GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsRankingCategories(
    BaseModel
):
    id: Optional[int]
    name: Optional[str]
    count: Optional[int]


class GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsPermitLevels(BaseModel):
    id: Optional[int]
    name: Optional[str]
    count: Optional[int]


class GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsCompetitionGroups(
    BaseModel
):
    id: Optional[int]
    name: Optional[str]
    count: Optional[int]


class GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsCompetitionSubgroups(
    BaseModel
):
    id: Optional[int]
    name: Optional[str]
    count: Optional[int]


GetMinisiteCalendarEvents.update_forward_refs()
GetMinisiteCalendarEventsGetMinisiteCalendarEvents.update_forward_refs()
GetMinisiteCalendarEventsGetMinisiteCalendarEventsParameters.update_forward_refs()
GetMinisiteCalendarEventsGetMinisiteCalendarEventsResults.update_forward_refs()
GetMinisiteCalendarEventsGetMinisiteCalendarEventsResultsUndeterminedCompetitionPeriod.update_forward_refs()
GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptions.update_forward_refs()
GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsRegions.update_forward_refs()
GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsRegionsWorld.update_forward_refs()
GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsRegionsArea.update_forward_refs()
GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsRegionsCountry.update_forward_refs()
GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsSeasons.update_forward_refs()
GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsDisciplines.update_forward_refs()
GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsRankingCategories.update_forward_refs()
GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsPermitLevels.update_forward_refs()
GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsCompetitionGroups.update_forward_refs()
GetMinisiteCalendarEventsGetMinisiteCalendarEventsOptionsCompetitionSubgroups.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetSingleCompetitorWinningStreak(BaseModel):
    get_single_competitor_winning_streak: Optional[
        "GetSingleCompetitorWinningStreakGetSingleCompetitorWinningStreak"
    ] = Field(alias="getSingleCompetitorWinningStreak")


class GetSingleCompetitorWinningStreakGetSingleCompetitorWinningStreak(BaseModel):
    parameters: Optional[
        "GetSingleCompetitorWinningStreakGetSingleCompetitorWinningStreakParameters"
    ]
    discipline_options: Optional[
        List[
            Optional[
                "GetSingleCompetitorWinningStreakGetSingleCompetitorWinningStreakDisciplineOptions"
            ]
        ]
    ] = Field(alias="disciplineOptions")
    streaks: Optional[
        List[
            Optional[
                "GetSingleCompetitorWinningStreakGetSingleCompetitorWinningStreakStreaks"
            ]
        ]
    ]


class GetSingleCompetitorWinningStreakGetSingleCompetitorWinningStreakParameters(
    BaseModel
):
    winning_streaks_discipline_option: Optional[str] = Field(
        alias="winningStreaksDisciplineOption"
    )
    winning_streaks_start_date: Optional[str] = Field(alias="winningStreaksStartDate")
    winning_streaks_end_date: Optional[str] = Field(alias="winningStreaksEndDate")
    winning_streaks_final_only: Optional[bool] = Field(alias="winningStreaksFinalOnly")


class GetSingleCompetitorWinningStreakGetSingleCompetitorWinningStreakDisciplineOptions(
    BaseModel
):
    id: Optional[str]
    name: Optional[str]


class GetSingleCompetitorWinningStreakGetSingleCompetitorWinningStreakStreaks(
    BaseModel
):
    length: Optional[int]
    results: Optional[
        List[
            Optional[
                "GetSingleCompetitorWinningStreakGetSingleCompetitorWinningStreakStreaksResults"
            ]
        ]
    ]


class GetSingleCompetitorWinningStreakGetSingleCompetitorWinningStreakStreaksResults(
    BaseModel
):
    date: Optional[str]
    venue: Optional[str]
    competition: Optional[str]
    race: Optional[str]
    result: Optional[str]
    discipline: Optional[str]


GetSingleCompetitorWinningStreak.update_forward_refs()
GetSingleCompetitorWinningStreakGetSingleCompetitorWinningStreak.update_forward_refs()
GetSingleCompetitorWinningStreakGetSingleCompetitorWinningStreakParameters.update_forward_refs()
GetSingleCompetitorWinningStreakGetSingleCompetitorWinningStreakDisciplineOptions.update_forward_refs()
GetSingleCompetitorWinningStreakGetSingleCompetitorWinningStreakStreaks.update_forward_refs()
GetSingleCompetitorWinningStreakGetSingleCompetitorWinningStreakStreaksResults.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetEventPhaseResults(BaseModel):
    get_event_phase_results: Optional[
        List[Optional["GetEventPhaseResultsGetEventPhaseResults"]]
    ] = Field(alias="getEventPhaseResults")


class GetEventPhaseResultsGetEventPhaseResults(BaseModel):
    id: Optional[int]
    updated_on: Optional[Any] = Field(alias="updatedOn")
    hash: Optional[str]
    phase_code: Optional[str] = Field(alias="phaseCode")
    phase_name: Optional[str] = Field(alias="phaseName")
    combined_type: Optional[str] = Field(alias="combinedType")
    event_i_d: Optional[int] = Field(alias="eventID")
    phase_date_and_time: Optional[Any] = Field(alias="phaseDateAndTime")
    sex_code: Optional[str] = Field(alias="sexCode")
    sex_name: Optional[str] = Field(alias="sexName")
    discipline: Optional["GetEventPhaseResultsGetEventPhaseResultsDiscipline"]
    is_startlist_published: Optional[bool] = Field(alias="isStartlistPublished")
    is_result_published: Optional[bool] = Field(alias="isResultPublished")
    is_phase_summary_published: Optional[bool] = Field(alias="isPhaseSummaryPublished")
    is_team_standing_published: Optional[bool] = Field(alias="isTeamStandingPublished")
    combined_discipline_order: Optional[int] = Field(alias="combinedDisciplineOrder")
    phase_order: Optional[int] = Field(alias="phaseOrder")
    phase_session_name: Optional[str] = Field(alias="phaseSessionName")
    phase_session_order: Optional[int] = Field(alias="phaseSessionOrder")
    status: Optional[int]
    has_time: Optional[bool] = Field(alias="hasTime")
    event_id__w_a: Optional[int] = Field(alias="eventId_WA")
    primary_phase_order: Optional[int] = Field(alias="primaryPhaseOrder")
    is_points_published: Optional[bool] = Field(alias="isPointsPublished")
    phase_name_url_slug: Optional[str] = Field(alias="phaseNameUrlSlug")
    sex_name_url_slug: Optional[str] = Field(alias="sexNameUrlSlug")
    result: Optional["GetEventPhaseResultsGetEventPhaseResultsResult"]


class GetEventPhaseResultsGetEventPhaseResultsDiscipline(BaseModel):
    updated_on: Optional[Any] = Field(alias="updatedOn")
    hash: Optional[str]
    id: Optional[str] = Field(alias="_id")
    name: Optional[str]
    type_code: Optional[str] = Field(alias="typeCode")
    type_name: Optional[str] = Field(alias="typeName")
    type_order: Optional[int] = Field(alias="typeOrder")
    order: Optional[int]
    is_track: Optional[bool] = Field(alias="isTrack")
    is_field: Optional[bool] = Field(alias="isField")
    is_road: Optional[bool] = Field(alias="isRoad")
    is_combined: Optional[bool] = Field(alias="isCombined")
    is_walk: Optional[bool] = Field(alias="isWalk")
    is_indoor: Optional[bool] = Field(alias="isIndoor")
    is_reaction: Optional[bool] = Field(alias="isReaction")
    is_outdoor: Optional[bool] = Field(alias="isOutdoor")
    is_wind: Optional[bool] = Field(alias="isWind")
    is_relay: Optional[bool] = Field(alias="isRelay")
    is_valid_i_a_a_f: Optional[bool] = Field(alias="isValidIAAF")
    name_url_slug: Optional[str] = Field(alias="nameUrlSlug")
    type_name_url_slug: Optional[str] = Field(alias="typeNameUrlSlug")


class GetEventPhaseResultsGetEventPhaseResultsResult(BaseModel):
    id: Optional[int]
    updated_on: Optional[Any] = Field(alias="updatedOn")
    competitor_id: Optional[int] = Field(alias="competitorId")
    team_id: Optional[int] = Field(alias="teamId")
    competitor_name: Optional[str] = Field(alias="competitorName")
    competitor_country_code: Optional[str] = Field(alias="competitorCountryCode")
    competitor_country_name: Optional[str] = Field(alias="competitorCountryName")
    competitor_birth_date: Optional[str] = Field(alias="competitorBirthDate")
    competitor_type_code: Optional[str] = Field(alias="competitorTypeCode")
    result_country_code: Optional[str] = Field(alias="resultCountryCode")
    result_mark: Optional[str] = Field(alias="resultMark")
    result_rank: Optional[int] = Field(alias="resultRank")
    result_order: Optional[int] = Field(alias="resultOrder")
    unit_id: Optional[int] = Field(alias="unitId")
    unit_code: Optional[str] = Field(alias="unitCode")
    unit_name: Optional[str] = Field(alias="unitName")
    unit_type_code: Optional[str] = Field(alias="unitTypeCode")
    unit_date_and_time: Optional[Any] = Field(alias="unitDateAndTime")
    event_i_d: Optional[int] = Field(alias="eventID")
    phase_i_d: Optional[int] = Field(alias="phaseID")
    standing_points: Optional[str] = Field(alias="standingPoints")
    discipline: Optional["GetEventPhaseResultsGetEventPhaseResultsResultDiscipline"]
    competitor_first_name: Optional[str] = Field(alias="competitorFirstName")
    competitor_last_name: Optional[str] = Field(alias="competitorLastName")
    result_country_name: Optional[str] = Field(alias="resultCountryName")


class GetEventPhaseResultsGetEventPhaseResultsResultDiscipline(BaseModel):
    updated_on: Optional[Any] = Field(alias="updatedOn")
    hash: Optional[str]
    id: Optional[str] = Field(alias="_id")
    name: Optional[str]
    type_code: Optional[str] = Field(alias="typeCode")
    type_name: Optional[str] = Field(alias="typeName")
    type_order: Optional[int] = Field(alias="typeOrder")
    order: Optional[int]
    is_track: Optional[bool] = Field(alias="isTrack")
    is_field: Optional[bool] = Field(alias="isField")
    is_road: Optional[bool] = Field(alias="isRoad")
    is_combined: Optional[bool] = Field(alias="isCombined")
    is_walk: Optional[bool] = Field(alias="isWalk")
    is_indoor: Optional[bool] = Field(alias="isIndoor")
    is_reaction: Optional[bool] = Field(alias="isReaction")
    is_outdoor: Optional[bool] = Field(alias="isOutdoor")
    is_wind: Optional[bool] = Field(alias="isWind")
    is_relay: Optional[bool] = Field(alias="isRelay")
    is_valid_i_a_a_f: Optional[bool] = Field(alias="isValidIAAF")
    name_url_slug: Optional[str] = Field(alias="nameUrlSlug")
    type_name_url_slug: Optional[str] = Field(alias="typeNameUrlSlug")


GetEventPhaseResults.update_forward_refs()
GetEventPhaseResultsGetEventPhaseResults.update_forward_refs()
GetEventPhaseResultsGetEventPhaseResultsDiscipline.update_forward_refs()
GetEventPhaseResultsGetEventPhaseResultsResult.update_forward_refs()
GetEventPhaseResultsGetEventPhaseResultsResultDiscipline.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetCombinedPoints(BaseModel):
    get_combined_points: Optional["GetCombinedPointsGetCombinedPoints"] = Field(
        alias="getCombinedPoints"
    )


class GetCombinedPointsGetCombinedPoints(BaseModel):
    all_disciplines: Optional[
        List[Optional["GetCombinedPointsGetCombinedPointsAllDisciplines"]]
    ] = Field(alias="allDisciplines")
    competitors: Optional[
        List[Optional["GetCombinedPointsGetCombinedPointsCompetitors"]]
    ]


class GetCombinedPointsGetCombinedPointsAllDisciplines(BaseModel):
    discipline_order: Optional[int] = Field(alias="disciplineOrder")
    discipline_id: Optional[str] = Field(alias="disciplineId")
    discipline_name: Optional[str] = Field(alias="disciplineName")


class GetCombinedPointsGetCombinedPointsCompetitors(BaseModel):
    competitor_name: Optional[str] = Field(alias="competitorName")
    competitor_first_name: Optional[str] = Field(alias="competitorFirstName")
    competitor_last_name: Optional[str] = Field(alias="competitorLastName")
    competitor_id__w_a: Optional[int] = Field(alias="competitorId_WA")
    competitor_country_code: Optional[str] = Field(alias="competitorCountryCode")
    competitor_country_name: Optional[str] = Field(alias="competitorCountryName")
    result_country_name: Optional[str] = Field(alias="resultCountryName")
    result_country_code: Optional[str] = Field(alias="resultCountryCode")
    total_result_mark: Optional[str] = Field(alias="totalResultMark")
    disciplines: Optional[
        List[Optional["GetCombinedPointsGetCombinedPointsCompetitorsDisciplines"]]
    ]


class GetCombinedPointsGetCombinedPointsCompetitorsDisciplines(BaseModel):
    result_mark: Optional[str] = Field(alias="resultMark")
    result_rank: Optional[int] = Field(alias="resultRank")
    result_order: Optional[int] = Field(alias="resultOrder")
    result_wind: Optional[str] = Field(alias="resultWind")
    summary_rank: Optional[int] = Field(alias="summaryRank")
    summary_points: Optional[int] = Field(alias="summaryPoints")
    overall_rank: Optional[int] = Field(alias="overallRank")
    record: Optional[str]
    discipline_order: Optional[int] = Field(alias="disciplineOrder")
    discipline_id: Optional[str] = Field(alias="disciplineId")
    discipline_name: Optional[str] = Field(alias="disciplineName")
    combined_points: Optional[str] = Field(alias="combinedPoints")
    points_tally: Optional[str] = Field(alias="pointsTally")


GetCombinedPoints.update_forward_refs()
GetCombinedPointsGetCombinedPoints.update_forward_refs()
GetCombinedPointsGetCombinedPointsAllDisciplines.update_forward_refs()
GetCombinedPointsGetCombinedPointsCompetitors.update_forward_refs()
GetCombinedPointsGetCombinedPointsCompetitorsDisciplines.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:50
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetWorldRankings(BaseModel):
    get_world_rankings: Optional["GetWorldRankingsGetWorldRankings"] = Field(
        alias="getWorldRankings"
    )


class GetWorldRankingsGetWorldRankings(BaseModel):
    parameters: Optional["GetWorldRankingsGetWorldRankingsParameters"]
    rank_date: Optional[str] = Field(alias="rankDate")
    event_group: Optional[str] = Field(alias="eventGroup")
    rankings: Optional[List[Optional["GetWorldRankingsGetWorldRankingsRankings"]]]


class GetWorldRankingsGetWorldRankingsParameters(BaseModel):
    rank_date: Optional[Any] = Field(alias="rankDate")
    gender: Optional[str]
    event_group: Optional[str] = Field(alias="eventGroup")
    region_type: Optional[str] = Field(alias="regionType")
    limited_by_country: Optional[int] = Field(alias="limitedByCountry")
    limit: Optional[int]


class GetWorldRankingsGetWorldRankingsRankings(BaseModel):
    id: int
    place: Optional[int]
    competitor_name: Optional[str] = Field(alias="competitorName")
    competitor_country_url_slug: Optional[str] = Field(alias="competitorCountryUrlSlug")
    competitor_url_slug: Optional[str] = Field(alias="competitorUrlSlug")
    competitor_birth_date: Optional[Any] = Field(alias="competitorBirthDate")
    country_code: Optional[str] = Field(alias="countryCode")
    ranking_score: Optional[int] = Field(alias="rankingScore")
    discipline_codes: Optional[List[Optional[str]]] = Field(alias="disciplineCodes")
    country_place: Optional[int] = Field(alias="countryPlace")
    previous_id: Optional[int] = Field(alias="previousId")
    previous_place: Optional[int] = Field(alias="previousPlace")
    previous_ranking_score: Optional[int] = Field(alias="previousRankingScore")


GetWorldRankings.update_forward_refs()
GetWorldRankingsGetWorldRankings.update_forward_refs()
GetWorldRankingsGetWorldRankingsParameters.update_forward_refs()
GetWorldRankingsGetWorldRankingsRankings.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:50
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetNewMedias(BaseModel):
    get_new_medias: Optional[List[Optional["GetNewMediasGetNewMedias"]]] = Field(
        alias="getNewMedias"
    )


class GetNewMediasGetNewMedias(BaseModel):
    id: Optional[str]
    media_type: Optional[str] = Field(alias="mediaType")
    title: Optional[str]
    copyright: Optional[str]
    file_name: Optional[str] = Field(alias="fileName")
    related_athletes: Optional[List[Optional[int]]] = Field(alias="relatedAthletes")
    related_disciplines: Optional[List[Optional[str]]] = Field(
        alias="relatedDisciplines"
    )
    related_competitions: Optional[List[Optional[str]]] = Field(
        alias="relatedCompetitions"
    )
    related_events: Optional[List[Optional[int]]] = Field(alias="relatedEvents")
    is_deleted: Optional[bool] = Field(alias="isDeleted")
    live_from: Optional[Any] = Field(alias="liveFrom")


GetNewMedias.update_forward_refs()
GetNewMediasGetNewMedias.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetHeroAthletesCarousel(BaseModel):
    get_hero_athletes_carousel: Optional[
        List[Optional["GetHeroAthletesCarouselGetHeroAthletesCarousel"]]
    ] = Field(alias="getHeroAthletesCarousel")


class GetHeroAthletesCarouselGetHeroAthletesCarousel(BaseModel):
    id: Optional[int]
    iaaf_id: Optional[int] = Field(alias="iaafId")
    first_name: Optional[str] = Field(alias="firstName")
    last_name: Optional[str] = Field(alias="lastName")
    friendly_name: Optional[str] = Field(alias="friendlyName")
    full_name: Optional[str] = Field(alias="fullName")
    friendly_name_letter: Optional[str] = Field(alias="friendlyNameLetter")
    friendly_name_first3_letter: Optional[str] = Field(alias="friendlyNameFirst3Letter")
    sex_code: Optional[str] = Field(alias="sexCode")
    sex_name: Optional[str] = Field(alias="sexName")
    country_code: Optional[str] = Field(alias="countryCode")
    country_name: Optional[str] = Field(alias="countryName")
    birth_date: Optional[Any] = Field(alias="birthDate")
    birth_place: Optional[str] = Field(alias="birthPlace")
    birth_place_country_name: Optional[str] = Field(alias="birthPlaceCountryName")
    sex_name_url_slug: Optional[str] = Field(alias="sexNameUrlSlug")
    country_url_slug: Optional[str] = Field(alias="countryUrlSlug")
    birth_place_country_url_slug: Optional[str] = Field(
        alias="birthPlaceCountryUrlSlug"
    )
    birth_country_code: Optional[str] = Field(alias="birthCountryCode")
    media_ids: Optional[List[Optional[str]]] = Field(alias="mediaIds")
    related_media: Optional[
        List[Optional["GetHeroAthletesCarouselGetHeroAthletesCarouselRelatedMedia"]]
    ] = Field(alias="relatedMedia")
    url_slug: Optional[str] = Field(alias="urlSlug")
    representative_id: Optional[int] = Field(alias="representativeId")
    biography: Optional[str]
    twitter_link: Optional[str] = Field(alias="twitterLink")
    instagram_link: Optional[str] = Field(alias="instagramLink")
    facebook_link: Optional[str] = Field(alias="facebookLink")
    transfers_of_allegiance: Optional[List[Optional[str]]] = Field(
        alias="transfersOfAllegiance"
    )
    aa_id: Optional[int] = Field(alias="aaId")
    country_full_name: Optional[str] = Field(alias="countryFullName")
    family_name: Optional[str] = Field(alias="familyName")
    given_name: Optional[str] = Field(alias="givenName")
    birth_date_str: Optional[str] = Field(alias="birthDateStr")
    facebook_username: Optional[str] = Field(alias="facebookUsername")
    twitter_username: Optional[str] = Field(alias="twitterUsername")
    instagram_username: Optional[str] = Field(alias="instagramUsername")


class GetHeroAthletesCarouselGetHeroAthletesCarouselRelatedMedia(BaseModel):
    id: Optional[str]
    media_type: Optional[str] = Field(alias="mediaType")
    title: Optional[str]
    copyright: Optional[str]
    file_name: Optional[str] = Field(alias="fileName")
    related_athletes: Optional[List[Optional[int]]] = Field(alias="relatedAthletes")
    related_disciplines: Optional[List[Optional[str]]] = Field(
        alias="relatedDisciplines"
    )
    related_competitions: Optional[List[Optional[str]]] = Field(
        alias="relatedCompetitions"
    )
    related_events: Optional[List[Optional[int]]] = Field(alias="relatedEvents")
    is_deleted: Optional[bool] = Field(alias="isDeleted")
    live_from: Optional[Any] = Field(alias="liveFrom")


GetHeroAthletesCarousel.update_forward_refs()
GetHeroAthletesCarouselGetHeroAthletesCarousel.update_forward_refs()
GetHeroAthletesCarouselGetHeroAthletesCarouselRelatedMedia.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetSingleCompetitorResultsByLimit(BaseModel):
    get_single_competitor_results_by_limit: Optional[
        "GetSingleCompetitorResultsByLimitGetSingleCompetitorResultsByLimit"
    ] = Field(alias="getSingleCompetitorResultsByLimit")


class GetSingleCompetitorResultsByLimitGetSingleCompetitorResultsByLimit(BaseModel):
    parameters: Optional[
        "GetSingleCompetitorResultsByLimitGetSingleCompetitorResultsByLimitParameters"
    ]
    disciplines: Optional[
        List[
            Optional[
                "GetSingleCompetitorResultsByLimitGetSingleCompetitorResultsByLimitDisciplines"
            ]
        ]
    ]
    results: Optional[
        List[
            Optional[
                "GetSingleCompetitorResultsByLimitGetSingleCompetitorResultsByLimitResults"
            ]
        ]
    ]


class GetSingleCompetitorResultsByLimitGetSingleCompetitorResultsByLimitParameters(
    BaseModel
):
    results_by_limits_discipline: Optional[str] = Field(
        alias="resultsByLimitsDiscipline"
    )
    results_by_limits_start_date: Optional[str] = Field(
        alias="resultsByLimitsStartDate"
    )
    results_by_limits_end_date: Optional[str] = Field(alias="resultsByLimitsEndDate")
    results_by_limits_only_regular: Optional[bool] = Field(
        alias="resultsByLimitsOnlyRegular"
    )


class GetSingleCompetitorResultsByLimitGetSingleCompetitorResultsByLimitDisciplines(
    BaseModel
):
    id: Optional[str]
    name: Optional[str]


class GetSingleCompetitorResultsByLimitGetSingleCompetitorResultsByLimitResults(
    BaseModel
):
    result: Optional[str]
    count: Optional[int]
    total_count: Optional[int] = Field(alias="totalCount")


GetSingleCompetitorResultsByLimit.update_forward_refs()
GetSingleCompetitorResultsByLimitGetSingleCompetitorResultsByLimit.update_forward_refs()
GetSingleCompetitorResultsByLimitGetSingleCompetitorResultsByLimitParameters.update_forward_refs()
GetSingleCompetitorResultsByLimitGetSingleCompetitorResultsByLimitDisciplines.update_forward_refs()
GetSingleCompetitorResultsByLimitGetSingleCompetitorResultsByLimitResults.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetCalendarEvents(BaseModel):
    get_calendar_events: Optional["GetCalendarEventsGetCalendarEvents"] = Field(
        alias="getCalendarEvents"
    )


class GetCalendarEventsGetCalendarEvents(BaseModel):
    hits: Optional[int]
    default_offset: Optional[int] = Field(alias="defaultOffset")
    pagination_page: Optional[int] = Field(alias="paginationPage")
    parameters: Optional["GetCalendarEventsGetCalendarEventsParameters"]
    results: Optional[List[Optional["GetCalendarEventsGetCalendarEventsResults"]]]
    options: Optional["GetCalendarEventsGetCalendarEventsOptions"]


class GetCalendarEventsGetCalendarEventsParameters(BaseModel):
    start_date: Optional[str] = Field(alias="startDate")
    end_date: Optional[str] = Field(alias="endDate")
    query: Optional[str]
    region_type: Optional[str] = Field(alias="regionType")
    region_id: Optional[int] = Field(alias="regionId")
    discipline_id: Optional[int] = Field(alias="disciplineId")
    ranking_category_id: Optional[int] = Field(alias="rankingCategoryId")
    permit_level_id: Optional[int] = Field(alias="permitLevelId")
    competition_group_id: Optional[int] = Field(alias="competitionGroupId")
    competition_subgroup_id: Optional[int] = Field(alias="competitionSubgroupId")
    limit: Optional[int]
    offset: Optional[int]
    show_options_with_no_hits: Optional[bool] = Field(alias="showOptionsWithNoHits")
    hide_competitions_with_no_results: Optional[bool] = Field(
        alias="hideCompetitionsWithNoResults"
    )
    season: Optional[str]


class GetCalendarEventsGetCalendarEventsResults(BaseModel):
    id: Optional[int]
    iaaf_id: Optional[int] = Field(alias="iaafId")
    has_results: Optional[bool] = Field(alias="hasResults")
    has_api_results: Optional[bool] = Field(alias="hasApiResults")
    has_startlist: Optional[bool] = Field(alias="hasStartlist")
    name: Optional[str]
    venue: Optional[str]
    area: Optional[str]
    country: Optional[str]
    ranking_category: Optional[str] = Field(alias="rankingCategory")
    disciplines: Optional[str]
    competition_group: Optional[str] = Field(alias="competitionGroup")
    competition_subgroup: Optional[str] = Field(alias="competitionSubgroup")
    start_date: Optional[str] = Field(alias="startDate")
    end_date: Optional[str] = Field(alias="endDate")
    date_range: Optional[str] = Field(alias="dateRange")
    season: Optional[str]
    was_url: Optional[str] = Field(alias="wasUrl")
    has_competition_information: Optional[bool] = Field(
        alias="hasCompetitionInformation"
    )
    undetermined_competition_period: Optional[
        "GetCalendarEventsGetCalendarEventsResultsUndeterminedCompetitionPeriod"
    ] = Field(alias="undeterminedCompetitionPeriod")


class GetCalendarEventsGetCalendarEventsResultsUndeterminedCompetitionPeriod(BaseModel):
    status: Optional[str]
    label: Optional[str]
    remark: Optional[str]


class GetCalendarEventsGetCalendarEventsOptions(BaseModel):
    regions: Optional["GetCalendarEventsGetCalendarEventsOptionsRegions"]
    seasons: Optional[
        List[Optional["GetCalendarEventsGetCalendarEventsOptionsSeasons"]]
    ]
    disciplines: Optional[
        List[Optional["GetCalendarEventsGetCalendarEventsOptionsDisciplines"]]
    ]
    ranking_categories: Optional[
        List[Optional["GetCalendarEventsGetCalendarEventsOptionsRankingCategories"]]
    ] = Field(alias="rankingCategories")
    permit_levels: Optional[
        List[Optional["GetCalendarEventsGetCalendarEventsOptionsPermitLevels"]]
    ] = Field(alias="permitLevels")
    competition_groups: Optional[
        List[Optional["GetCalendarEventsGetCalendarEventsOptionsCompetitionGroups"]]
    ] = Field(alias="competitionGroups")
    competition_subgroups: Optional[
        List[Optional["GetCalendarEventsGetCalendarEventsOptionsCompetitionSubgroups"]]
    ] = Field(alias="competitionSubgroups")


class GetCalendarEventsGetCalendarEventsOptionsRegions(BaseModel):
    world: Optional[
        List[Optional["GetCalendarEventsGetCalendarEventsOptionsRegionsWorld"]]
    ]
    area: Optional[
        List[Optional["GetCalendarEventsGetCalendarEventsOptionsRegionsArea"]]
    ]
    country: Optional[
        List[Optional["GetCalendarEventsGetCalendarEventsOptionsRegionsCountry"]]
    ]


class GetCalendarEventsGetCalendarEventsOptionsRegionsWorld(BaseModel):
    id: Optional[int]
    name: Optional[str]
    count: Optional[int]


class GetCalendarEventsGetCalendarEventsOptionsRegionsArea(BaseModel):
    id: Optional[int]
    name: Optional[str]
    count: Optional[int]


class GetCalendarEventsGetCalendarEventsOptionsRegionsCountry(BaseModel):
    id: Optional[int]
    name: Optional[str]
    count: Optional[int]


class GetCalendarEventsGetCalendarEventsOptionsSeasons(BaseModel):
    id: Optional[str]
    name: Optional[str]


class GetCalendarEventsGetCalendarEventsOptionsDisciplines(BaseModel):
    id: Optional[int]
    name: Optional[str]
    count: Optional[int]


class GetCalendarEventsGetCalendarEventsOptionsRankingCategories(BaseModel):
    id: Optional[int]
    name: Optional[str]
    count: Optional[int]


class GetCalendarEventsGetCalendarEventsOptionsPermitLevels(BaseModel):
    id: Optional[int]
    name: Optional[str]
    count: Optional[int]


class GetCalendarEventsGetCalendarEventsOptionsCompetitionGroups(BaseModel):
    id: Optional[int]
    name: Optional[str]
    count: Optional[int]


class GetCalendarEventsGetCalendarEventsOptionsCompetitionSubgroups(BaseModel):
    id: Optional[int]
    name: Optional[str]
    count: Optional[int]


GetCalendarEvents.update_forward_refs()
GetCalendarEventsGetCalendarEvents.update_forward_refs()
GetCalendarEventsGetCalendarEventsParameters.update_forward_refs()
GetCalendarEventsGetCalendarEventsResults.update_forward_refs()
GetCalendarEventsGetCalendarEventsResultsUndeterminedCompetitionPeriod.update_forward_refs()
GetCalendarEventsGetCalendarEventsOptions.update_forward_refs()
GetCalendarEventsGetCalendarEventsOptionsRegions.update_forward_refs()
GetCalendarEventsGetCalendarEventsOptionsRegionsWorld.update_forward_refs()
GetCalendarEventsGetCalendarEventsOptionsRegionsArea.update_forward_refs()
GetCalendarEventsGetCalendarEventsOptionsRegionsCountry.update_forward_refs()
GetCalendarEventsGetCalendarEventsOptionsSeasons.update_forward_refs()
GetCalendarEventsGetCalendarEventsOptionsDisciplines.update_forward_refs()
GetCalendarEventsGetCalendarEventsOptionsRankingCategories.update_forward_refs()
GetCalendarEventsGetCalendarEventsOptionsPermitLevels.update_forward_refs()
GetCalendarEventsGetCalendarEventsOptionsCompetitionGroups.update_forward_refs()
GetCalendarEventsGetCalendarEventsOptionsCompetitionSubgroups.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:50
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetCompetitorsLegacyPrimaryMedia(BaseModel):
    get_competitors_legacy_primary_media: Optional[
        List[
            Optional["GetCompetitorsLegacyPrimaryMediaGetCompetitorsLegacyPrimaryMedia"]
        ]
    ] = Field(alias="getCompetitorsLegacyPrimaryMedia")


class GetCompetitorsLegacyPrimaryMediaGetCompetitorsLegacyPrimaryMedia(BaseModel):
    id: Optional[str]
    competitor_id: Optional[int] = Field(alias="competitorId")
    file_name: Optional[str] = Field(alias="fileName")


GetCompetitorsLegacyPrimaryMedia.update_forward_refs()
GetCompetitorsLegacyPrimaryMediaGetCompetitorsLegacyPrimaryMedia.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetSingleCompetitorResultsDiscipline(BaseModel):
    get_single_competitor_results_discipline: Optional[
        "GetSingleCompetitorResultsDisciplineGetSingleCompetitorResultsDiscipline"
    ] = Field(alias="getSingleCompetitorResultsDiscipline")


class GetSingleCompetitorResultsDisciplineGetSingleCompetitorResultsDiscipline(
    BaseModel
):
    parameters: Optional[
        "GetSingleCompetitorResultsDisciplineGetSingleCompetitorResultsDisciplineParameters"
    ]
    active_years: Optional[List[Optional[str]]] = Field(alias="activeYears")
    results_by_event: Optional[
        List[
            Optional[
                "GetSingleCompetitorResultsDisciplineGetSingleCompetitorResultsDisciplineResultsByEvent"
            ]
        ]
    ] = Field(alias="resultsByEvent")
    results_by_date: Optional[
        List[
            Optional[
                "GetSingleCompetitorResultsDisciplineGetSingleCompetitorResultsDisciplineResultsByDate"
            ]
        ]
    ] = Field(alias="resultsByDate")


class GetSingleCompetitorResultsDisciplineGetSingleCompetitorResultsDisciplineParameters(
    BaseModel
):
    results_by_year: Optional[int] = Field(alias="resultsByYear")
    results_by_year_order_by: Optional[str] = Field(alias="resultsByYearOrderBy")


class GetSingleCompetitorResultsDisciplineGetSingleCompetitorResultsDisciplineResultsByEvent(
    BaseModel
):
    indoor: Optional[bool]
    discipline_code: Optional[str] = Field(alias="disciplineCode")
    discipline_name_url_slug: Optional[str] = Field(alias="disciplineNameUrlSlug")
    type_name_url_slug: Optional[str] = Field(alias="typeNameUrlSlug")
    discipline: Optional[str]
    with_wind: Optional[bool] = Field(alias="withWind")
    results: Optional[
        List[
            Optional[
                "GetSingleCompetitorResultsDisciplineGetSingleCompetitorResultsDisciplineResultsByEventResults"
            ]
        ]
    ]


class GetSingleCompetitorResultsDisciplineGetSingleCompetitorResultsDisciplineResultsByEventResults(
    BaseModel
):
    date: Optional[str]
    competition: Optional[str]
    venue: Optional[str]
    indoor: Optional[bool]
    country: Optional[str]
    category: Optional[str]
    race: Optional[str]
    place: Optional[str]
    mark: Optional[str]
    wind: Optional[str]
    not_legal: Optional[bool] = Field(alias="notLegal")
    result_score: Optional[int] = Field(alias="resultScore")
    remark: Optional[str]


class GetSingleCompetitorResultsDisciplineGetSingleCompetitorResultsDisciplineResultsByDate(
    BaseModel
):
    date: Optional[str]
    competition: Optional[str]
    venue: Optional[str]
    indoor: Optional[bool]
    country: Optional[str]
    category: Optional[str]
    race: Optional[str]
    place: Optional[str]
    mark: Optional[str]
    wind: Optional[str]
    not_legal: Optional[bool] = Field(alias="notLegal")
    result_score: Optional[int] = Field(alias="resultScore")
    remark: Optional[str]


GetSingleCompetitorResultsDiscipline.update_forward_refs()
GetSingleCompetitorResultsDisciplineGetSingleCompetitorResultsDiscipline.update_forward_refs()
GetSingleCompetitorResultsDisciplineGetSingleCompetitorResultsDisciplineParameters.update_forward_refs()
GetSingleCompetitorResultsDisciplineGetSingleCompetitorResultsDisciplineResultsByEvent.update_forward_refs()
GetSingleCompetitorResultsDisciplineGetSingleCompetitorResultsDisciplineResultsByEventResults.update_forward_refs()
GetSingleCompetitorResultsDisciplineGetSingleCompetitorResultsDisciplineResultsByDate.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:50
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetWawMenu(BaseModel):
    get_waw_menu: Optional["GetWawMenuGetWawMenu"] = Field(alias="getWawMenu")


class GetWawMenuGetWawMenu(BaseModel):
    id: Optional[str]
    title: Optional[str]
    type: Optional[str]
    is_visible: Optional[bool] = Field(alias="isVisible")
    event_id: Optional[int] = Field(alias="eventId")
    event: Optional["GetWawMenuGetWawMenuEvent"]
    items: Optional[List[Optional["GetWawMenuGetWawMenuItems"]]]


class GetWawMenuGetWawMenuEvent(BaseModel):
    id: Optional[int]
    updated_on: Optional[Any] = Field(alias="updatedOn")
    name: Optional[str]
    start_date: Optional[Any] = Field(alias="startDate")
    end_date: Optional[Any] = Field(alias="endDate")
    hash: Optional[str]
    venue: Optional[str]
    country_code: Optional[str] = Field(alias="countryCode")
    country_name: Optional[str] = Field(alias="countryName")
    area_code: Optional[str] = Field(alias="areaCode")
    area_name: Optional[str] = Field(alias="areaName")
    age_code: Optional[str] = Field(alias="ageCode")
    indoor_outdoor: Optional[str] = Field(alias="indoorOutdoor")
    category_code: Optional[str] = Field(alias="categoryCode")
    category_name: Optional[str] = Field(alias="categoryName")
    category_order: Optional[int] = Field(alias="categoryOrder")
    sub_category_code: Optional[str] = Field(alias="subCategoryCode")
    sub_category_name: Optional[str] = Field(alias="subCategoryName")
    show_web_live_banner: Optional[bool] = Field(alias="showWebLiveBanner")
    sub_category_order: Optional[int] = Field(alias="subCategoryOrder")
    class_code: Optional[str] = Field(alias="classCode")
    class_order: Optional[int] = Field(alias="classOrder")
    is_published: Optional[bool] = Field(alias="isPublished")
    has_comp_doc_results: Optional[bool] = Field(alias="hasCompDocResults")
    name_url_slug: Optional[str] = Field(alias="nameUrlSlug")
    start_date_year: Optional[int] = Field(alias="startDateYear")
    circuits: Optional[List[Optional["GetWawMenuGetWawMenuEventCircuits"]]]
    area_name_url_slug: Optional[str] = Field(alias="areaNameUrlSlug")
    category_name_url_slug: Optional[str] = Field(alias="categoryNameUrlSlug")
    sub_category_name_url_slug: Optional[str] = Field(alias="subCategoryNameUrlSlug")
    discipline_codes: Optional[List[Optional[str]]] = Field(alias="disciplineCodes")
    event_id__w_a: Optional[int] = Field(alias="eventId_WA")
    has_timetable: Optional[bool] = Field(alias="hasTimetable")
    page: Optional["GetWawMenuGetWawMenuEventPage"]
    event_start_date_time: Optional[Any] = Field(alias="eventStartDateTime")
    event_end_date_time: Optional[Any] = Field(alias="eventEndDateTime")
    venue_timezone: Optional[str] = Field(alias="venueTimezone")


class GetWawMenuGetWawMenuEventCircuits(BaseModel):
    updated_on: Optional[Any] = Field(alias="UpdatedOn")
    hash: Optional[str]
    circuit_code: Optional[str] = Field(alias="circuitCode")
    circuit_type_code: Optional[str] = Field(alias="circuitTypeCode")
    circuit_name: Optional[str] = Field(alias="circuitName")
    season: Optional[int]
    circuit_order: Optional[int] = Field(alias="circuitOrder")
    circuit_type_name: Optional[str] = Field(alias="circuitTypeName")


class GetWawMenuGetWawMenuEventPage(BaseModel):
    id: Optional[str]
    type_id: Optional[str] = Field(alias="typeId")
    language: Optional[str]
    title: Optional[str]
    competition_id: Optional[str] = Field(alias="competitionId")
    event_id: Optional[int] = Field(alias="eventId")
    event: Optional["GetWawMenuGetWawMenuEventPageEvent"]
    site_id: Optional[str] = Field(alias="siteId")
    minisite: Optional["GetWawMenuGetWawMenuEventPageMinisite"]
    seo_description: Optional[str] = Field(alias="seoDescription")
    slug: Optional[str]
    published_by_id: Optional[str] = Field(alias="publishedById")
    published_by_name: Optional[str] = Field(alias="publishedByName")
    published: Optional[Any]
    content_modules: Optional[
        List[Optional["GetWawMenuGetWawMenuEventPageContentModules"]]
    ] = Field(alias="contentModules")
    gated_content: Optional[bool] = Field(alias="gatedContent")
    campaign_id: Optional[str] = Field(alias="campaignId")
    campaign: Optional["GetWawMenuGetWawMenuEventPageCampaign"]


class GetWawMenuGetWawMenuEventPageEvent(BaseModel):
    id: Optional[int]
    updated_on: Optional[Any] = Field(alias="updatedOn")
    name: Optional[str]
    start_date: Optional[Any] = Field(alias="startDate")
    end_date: Optional[Any] = Field(alias="endDate")
    hash: Optional[str]
    venue: Optional[str]
    country_code: Optional[str] = Field(alias="countryCode")
    country_name: Optional[str] = Field(alias="countryName")
    area_code: Optional[str] = Field(alias="areaCode")
    area_name: Optional[str] = Field(alias="areaName")
    age_code: Optional[str] = Field(alias="ageCode")
    indoor_outdoor: Optional[str] = Field(alias="indoorOutdoor")
    category_code: Optional[str] = Field(alias="categoryCode")
    category_name: Optional[str] = Field(alias="categoryName")
    category_order: Optional[int] = Field(alias="categoryOrder")
    sub_category_code: Optional[str] = Field(alias="subCategoryCode")
    sub_category_name: Optional[str] = Field(alias="subCategoryName")
    show_web_live_banner: Optional[bool] = Field(alias="showWebLiveBanner")
    sub_category_order: Optional[int] = Field(alias="subCategoryOrder")
    class_code: Optional[str] = Field(alias="classCode")
    class_order: Optional[int] = Field(alias="classOrder")
    is_published: Optional[bool] = Field(alias="isPublished")
    has_comp_doc_results: Optional[bool] = Field(alias="hasCompDocResults")
    name_url_slug: Optional[str] = Field(alias="nameUrlSlug")
    start_date_year: Optional[int] = Field(alias="startDateYear")
    area_name_url_slug: Optional[str] = Field(alias="areaNameUrlSlug")
    category_name_url_slug: Optional[str] = Field(alias="categoryNameUrlSlug")
    sub_category_name_url_slug: Optional[str] = Field(alias="subCategoryNameUrlSlug")
    discipline_codes: Optional[List[Optional[str]]] = Field(alias="disciplineCodes")
    event_id__w_a: Optional[int] = Field(alias="eventId_WA")
    has_timetable: Optional[bool] = Field(alias="hasTimetable")
    event_start_date_time: Optional[Any] = Field(alias="eventStartDateTime")
    event_end_date_time: Optional[Any] = Field(alias="eventEndDateTime")
    venue_timezone: Optional[str] = Field(alias="venueTimezone")


class GetWawMenuGetWawMenuEventPageMinisite(BaseModel):
    id: Optional[str]
    name: Optional[str]
    logo_id: Optional[str] = Field(alias="logoId")
    logo_edited: Optional[str] = Field(alias="logoEdited")
    feature_image_id: Optional[str] = Field(alias="featureImageId")
    feature_image_edited: Optional[str] = Field(alias="featureImageEdited")
    theme: Optional[str]
    default_sponsor_ids: Optional[List[Optional[str]]] = Field(
        alias="defaultSponsorIds"
    )
    sponsor_ids: Optional[List[Optional[str]]] = Field(alias="sponsorIds")
    event_id: Optional[int] = Field(alias="eventId")
    primary_color: Optional[str] = Field(alias="primaryColor")
    secondary_color: Optional[str] = Field(alias="secondaryColor")
    tertiary_color: Optional[str] = Field(alias="tertiaryColor")
    additional_colours: Optional[List[Optional[str]]] = Field(alias="additionalColours")
    language_codes: Optional[List[Optional[str]]] = Field(alias="languageCodes")


class GetWawMenuGetWawMenuEventPageContentModules(BaseModel):
    module_type: Optional[str] = Field(alias="moduleType")
    language: Optional[str]
    related_article_ids: List[Optional[str]] = Field(alias="relatedArticleIds")
    event_ids: List[Optional[int]] = Field(alias="eventIds")
    related_competitor_ids: List[Optional[int]] = Field(alias="relatedCompetitorIds")
    related_discipline_codes: Optional[List[Optional[str]]] = Field(
        alias="relatedDisciplineCodes"
    )
    athlete_ids: Optional[List[Optional[str]]] = Field(alias="athleteIds")
    media_ids: List[Optional[str]] = Field(alias="mediaIds")
    social_links: Optional[List[Optional[str]]] = Field(alias="socialLinks")
    minisite_id: Optional[str] = Field(alias="minisiteId")
    location_id: Optional[str] = Field(alias="locationId")
    event_id: Optional[int] = Field(alias="eventId")
    tags: Optional[List[Optional[str]]]
    description: Optional[str]
    event_name: Optional[str] = Field(alias="eventName")
    tag_id: Optional[str] = Field(alias="tagId")
    more_news_link: Optional[str] = Field(alias="moreNewsLink")
    more_news_text: Optional[str] = Field(alias="moreNewsText")
    colour: Optional[str]
    image_edited: Optional[str] = Field(alias="imageEdited")
    text_position: Optional[str] = Field(alias="textPosition")
    text_colour: Optional[str] = Field(alias="textColour")
    title: Optional[str]
    top_title: Optional[str] = Field(alias="topTitle")
    bottom_title: Optional[str] = Field(alias="bottomTitle")
    subtitle: Optional[str]
    category: Optional[str]
    standfirst: Optional[str]
    url: Optional[str]
    button_text: Optional[str] = Field(alias="buttonText")
    image_position: Optional[str] = Field(alias="imagePosition")
    background_color: Optional[str] = Field(alias="backgroundColor")
    show_timestamp: Optional[bool] = Field(alias="showTimestamp")
    content: Optional[str]
    parent_id: Optional[str] = Field(alias="parentId")
    event_id_wa: Optional[int] = Field(alias="eventIdWa")
    layout: Optional[int]
    slug: Optional[str]
    video_ids: Optional[List[Optional[str]]] = Field(alias="videoIds")
    video_playlist_id: Optional[str] = Field(alias="videoPlaylistId")
    video_id: Optional[str] = Field(alias="videoId")


class GetWawMenuGetWawMenuEventPageCampaign(BaseModel):
    id: Optional[str]
    name: Optional[str]
    tag: Optional[str]
    type: Optional[str]
    description: Optional[str]
    thank_you_message: Optional[str] = Field(alias="thankYouMessage")
    already_signed_message: Optional[str] = Field(alias="alreadySignedMessage")
    close_date: Optional[Any] = Field(alias="closeDate")
    redirect_url: Optional[str] = Field(alias="redirectUrl")
    tag_user_friendly_name: Optional[str] = Field(alias="tagUserFriendlyName")
    background_image_edited: Optional[str] = Field(alias="backgroundImageEdited")
    header_image_edited: Optional[str] = Field(alias="headerImageEdited")
    visible_on_preference_center: Optional[bool] = Field(
        alias="visibleOnPreferenceCenter"
    )
    short_form: Optional[bool] = Field(alias="shortForm")
    top_level_bucket_id: Optional[str] = Field(alias="topLevelBucketId")


class GetWawMenuGetWawMenuItems(BaseModel):
    title: Optional[str]
    is_visible: Optional[bool] = Field(alias="isVisible")
    page_id: Optional[str] = Field(alias="pageId")
    page: Optional["GetWawMenuGetWawMenuItemsPage"]
    items: Optional[List[Optional["GetWawMenuGetWawMenuItemsItems"]]]


class GetWawMenuGetWawMenuItemsPage(BaseModel):
    id: Optional[str]
    type_id: Optional[str] = Field(alias="typeId")
    language: Optional[str]
    title: Optional[str]
    competition_id: Optional[str] = Field(alias="competitionId")
    event_id: Optional[int] = Field(alias="eventId")
    event: Optional["GetWawMenuGetWawMenuItemsPageEvent"]
    site_id: Optional[str] = Field(alias="siteId")
    minisite: Optional["GetWawMenuGetWawMenuItemsPageMinisite"]
    seo_description: Optional[str] = Field(alias="seoDescription")
    slug: Optional[str]
    published_by_id: Optional[str] = Field(alias="publishedById")
    published_by_name: Optional[str] = Field(alias="publishedByName")
    published: Optional[Any]
    content_modules: Optional[
        List[Optional["GetWawMenuGetWawMenuItemsPageContentModules"]]
    ] = Field(alias="contentModules")
    gated_content: Optional[bool] = Field(alias="gatedContent")
    campaign_id: Optional[str] = Field(alias="campaignId")
    campaign: Optional["GetWawMenuGetWawMenuItemsPageCampaign"]


class GetWawMenuGetWawMenuItemsPageEvent(BaseModel):
    id: Optional[int]
    updated_on: Optional[Any] = Field(alias="updatedOn")
    name: Optional[str]
    start_date: Optional[Any] = Field(alias="startDate")
    end_date: Optional[Any] = Field(alias="endDate")
    hash: Optional[str]
    venue: Optional[str]
    country_code: Optional[str] = Field(alias="countryCode")
    country_name: Optional[str] = Field(alias="countryName")
    area_code: Optional[str] = Field(alias="areaCode")
    area_name: Optional[str] = Field(alias="areaName")
    age_code: Optional[str] = Field(alias="ageCode")
    indoor_outdoor: Optional[str] = Field(alias="indoorOutdoor")
    category_code: Optional[str] = Field(alias="categoryCode")
    category_name: Optional[str] = Field(alias="categoryName")
    category_order: Optional[int] = Field(alias="categoryOrder")
    sub_category_code: Optional[str] = Field(alias="subCategoryCode")
    sub_category_name: Optional[str] = Field(alias="subCategoryName")
    show_web_live_banner: Optional[bool] = Field(alias="showWebLiveBanner")
    sub_category_order: Optional[int] = Field(alias="subCategoryOrder")
    class_code: Optional[str] = Field(alias="classCode")
    class_order: Optional[int] = Field(alias="classOrder")
    is_published: Optional[bool] = Field(alias="isPublished")
    has_comp_doc_results: Optional[bool] = Field(alias="hasCompDocResults")
    name_url_slug: Optional[str] = Field(alias="nameUrlSlug")
    start_date_year: Optional[int] = Field(alias="startDateYear")
    area_name_url_slug: Optional[str] = Field(alias="areaNameUrlSlug")
    category_name_url_slug: Optional[str] = Field(alias="categoryNameUrlSlug")
    sub_category_name_url_slug: Optional[str] = Field(alias="subCategoryNameUrlSlug")
    discipline_codes: Optional[List[Optional[str]]] = Field(alias="disciplineCodes")
    event_id__w_a: Optional[int] = Field(alias="eventId_WA")
    has_timetable: Optional[bool] = Field(alias="hasTimetable")
    event_start_date_time: Optional[Any] = Field(alias="eventStartDateTime")
    event_end_date_time: Optional[Any] = Field(alias="eventEndDateTime")
    venue_timezone: Optional[str] = Field(alias="venueTimezone")


class GetWawMenuGetWawMenuItemsPageMinisite(BaseModel):
    id: Optional[str]
    name: Optional[str]
    logo_id: Optional[str] = Field(alias="logoId")
    logo_edited: Optional[str] = Field(alias="logoEdited")
    feature_image_id: Optional[str] = Field(alias="featureImageId")
    feature_image_edited: Optional[str] = Field(alias="featureImageEdited")
    theme: Optional[str]
    default_sponsor_ids: Optional[List[Optional[str]]] = Field(
        alias="defaultSponsorIds"
    )
    sponsor_ids: Optional[List[Optional[str]]] = Field(alias="sponsorIds")
    event_id: Optional[int] = Field(alias="eventId")
    primary_color: Optional[str] = Field(alias="primaryColor")
    secondary_color: Optional[str] = Field(alias="secondaryColor")
    tertiary_color: Optional[str] = Field(alias="tertiaryColor")
    additional_colours: Optional[List[Optional[str]]] = Field(alias="additionalColours")
    language_codes: Optional[List[Optional[str]]] = Field(alias="languageCodes")


class GetWawMenuGetWawMenuItemsPageContentModules(BaseModel):
    module_type: Optional[str] = Field(alias="moduleType")
    language: Optional[str]
    related_article_ids: List[Optional[str]] = Field(alias="relatedArticleIds")
    event_ids: List[Optional[int]] = Field(alias="eventIds")
    related_competitor_ids: List[Optional[int]] = Field(alias="relatedCompetitorIds")
    related_discipline_codes: Optional[List[Optional[str]]] = Field(
        alias="relatedDisciplineCodes"
    )
    athlete_ids: Optional[List[Optional[str]]] = Field(alias="athleteIds")
    media_ids: List[Optional[str]] = Field(alias="mediaIds")
    social_links: Optional[List[Optional[str]]] = Field(alias="socialLinks")
    minisite_id: Optional[str] = Field(alias="minisiteId")
    location_id: Optional[str] = Field(alias="locationId")
    event_id: Optional[int] = Field(alias="eventId")
    tags: Optional[List[Optional[str]]]
    description: Optional[str]
    event_name: Optional[str] = Field(alias="eventName")
    tag_id: Optional[str] = Field(alias="tagId")
    more_news_link: Optional[str] = Field(alias="moreNewsLink")
    more_news_text: Optional[str] = Field(alias="moreNewsText")
    colour: Optional[str]
    image_edited: Optional[str] = Field(alias="imageEdited")
    text_position: Optional[str] = Field(alias="textPosition")
    text_colour: Optional[str] = Field(alias="textColour")
    title: Optional[str]
    top_title: Optional[str] = Field(alias="topTitle")
    bottom_title: Optional[str] = Field(alias="bottomTitle")
    subtitle: Optional[str]
    category: Optional[str]
    standfirst: Optional[str]
    url: Optional[str]
    button_text: Optional[str] = Field(alias="buttonText")
    image_position: Optional[str] = Field(alias="imagePosition")
    background_color: Optional[str] = Field(alias="backgroundColor")
    show_timestamp: Optional[bool] = Field(alias="showTimestamp")
    content: Optional[str]
    parent_id: Optional[str] = Field(alias="parentId")
    event_id_wa: Optional[int] = Field(alias="eventIdWa")
    layout: Optional[int]
    slug: Optional[str]
    video_ids: Optional[List[Optional[str]]] = Field(alias="videoIds")
    video_playlist_id: Optional[str] = Field(alias="videoPlaylistId")
    video_id: Optional[str] = Field(alias="videoId")


class GetWawMenuGetWawMenuItemsPageCampaign(BaseModel):
    id: Optional[str]
    name: Optional[str]
    tag: Optional[str]
    type: Optional[str]
    description: Optional[str]
    thank_you_message: Optional[str] = Field(alias="thankYouMessage")
    already_signed_message: Optional[str] = Field(alias="alreadySignedMessage")
    close_date: Optional[Any] = Field(alias="closeDate")
    redirect_url: Optional[str] = Field(alias="redirectUrl")
    tag_user_friendly_name: Optional[str] = Field(alias="tagUserFriendlyName")
    background_image_edited: Optional[str] = Field(alias="backgroundImageEdited")
    header_image_edited: Optional[str] = Field(alias="headerImageEdited")
    visible_on_preference_center: Optional[bool] = Field(
        alias="visibleOnPreferenceCenter"
    )
    short_form: Optional[bool] = Field(alias="shortForm")
    top_level_bucket_id: Optional[str] = Field(alias="topLevelBucketId")


class GetWawMenuGetWawMenuItemsItems(BaseModel):
    title: Optional[str]
    is_visible: Optional[bool] = Field(alias="isVisible")
    page_id: Optional[str] = Field(alias="pageId")
    page: Optional["GetWawMenuGetWawMenuItemsItemsPage"]
    items: Optional[List[Optional["GetWawMenuGetWawMenuItemsItemsItems"]]]


class GetWawMenuGetWawMenuItemsItemsPage(BaseModel):
    id: Optional[str]
    type_id: Optional[str] = Field(alias="typeId")
    language: Optional[str]
    title: Optional[str]
    competition_id: Optional[str] = Field(alias="competitionId")
    event_id: Optional[int] = Field(alias="eventId")
    site_id: Optional[str] = Field(alias="siteId")
    seo_description: Optional[str] = Field(alias="seoDescription")
    slug: Optional[str]
    published_by_id: Optional[str] = Field(alias="publishedById")
    published_by_name: Optional[str] = Field(alias="publishedByName")
    published: Optional[Any]
    gated_content: Optional[bool] = Field(alias="gatedContent")
    campaign_id: Optional[str] = Field(alias="campaignId")


class GetWawMenuGetWawMenuItemsItemsItems(BaseModel):
    title: Optional[str]
    is_visible: Optional[bool] = Field(alias="isVisible")
    page_id: Optional[str] = Field(alias="pageId")


GetWawMenu.update_forward_refs()
GetWawMenuGetWawMenu.update_forward_refs()
GetWawMenuGetWawMenuEvent.update_forward_refs()
GetWawMenuGetWawMenuEventCircuits.update_forward_refs()
GetWawMenuGetWawMenuEventPage.update_forward_refs()
GetWawMenuGetWawMenuEventPageEvent.update_forward_refs()
GetWawMenuGetWawMenuEventPageMinisite.update_forward_refs()
GetWawMenuGetWawMenuEventPageContentModules.update_forward_refs()
GetWawMenuGetWawMenuEventPageCampaign.update_forward_refs()
GetWawMenuGetWawMenuItems.update_forward_refs()
GetWawMenuGetWawMenuItemsPage.update_forward_refs()
GetWawMenuGetWawMenuItemsPageEvent.update_forward_refs()
GetWawMenuGetWawMenuItemsPageMinisite.update_forward_refs()
GetWawMenuGetWawMenuItemsPageContentModules.update_forward_refs()
GetWawMenuGetWawMenuItemsPageCampaign.update_forward_refs()
GetWawMenuGetWawMenuItemsItems.update_forward_refs()
GetWawMenuGetWawMenuItemsItemsPage.update_forward_refs()
GetWawMenuGetWawMenuItemsItemsItems.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:50
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetVoteOptions(BaseModel):
    get_vote_options: Optional[List[Optional["GetVoteOptionsGetVoteOptions"]]] = Field(
        alias="getVoteOptions"
    )


class GetVoteOptionsGetVoteOptions(BaseModel):
    id: Optional[str]
    order: Optional[int]
    vote_id: Optional[str] = Field(alias="voteId")
    vote_name: Optional[str] = Field(alias="voteName")
    option_year: Optional[int] = Field(alias="optionYear")
    option_athlete_name: Optional[str] = Field(alias="optionAthleteName")
    option_description: Optional[str] = Field(alias="optionDescription")
    image_url: Optional[str] = Field(alias="imageUrl")
    votes_count: Optional[int] = Field(alias="votesCount")


GetVoteOptions.update_forward_refs()
GetVoteOptionsGetVoteOptions.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetTeamScoring(BaseModel):
    get_team_scoring: Optional[List[Optional["GetTeamScoringGetTeamScoring"]]] = Field(
        alias="getTeamScoring"
    )


class GetTeamScoringGetTeamScoring(BaseModel):
    id: str
    team_id: Optional[int] = Field(alias="teamId")
    team_id__w_a: Optional[int] = Field(alias="teamId_WA")
    phase_id: Optional[int] = Field(alias="phaseId")
    unit_id: Optional[int] = Field(alias="unitId")
    result_id: Optional[int] = Field(alias="resultId")
    team_name: Optional[str] = Field(alias="teamName")
    team_country_code: Optional[str] = Field(alias="teamCountryCode")
    competitor_id: Optional[List[Optional[int]]] = Field(alias="competitorId")
    athlete: Optional[List[Optional["GetTeamScoringGetTeamScoringAthlete"]]]
    updated_on: Optional[Any] = Field(alias="updatedOn")
    scoring_team_id: Optional[int] = Field(alias="scoringTeamId")
    scoring_team_order: Optional[int] = Field(alias="scoringTeamOrder")
    scoring_team_detail_order: Optional[int] = Field(alias="scoringTeamDetailOrder")
    bib: Optional[str]
    event_store_id: Optional[str] = Field(alias="eventStoreId")
    chunk_order: Optional[int] = Field(alias="chunkOrder")
    chunk_id: Optional[str] = Field(alias="chunkId")


class GetTeamScoringGetTeamScoringAthlete(BaseModel):
    competitor_id: Optional[List[Optional[int]]] = Field(alias="competitorId")
    detail: Optional[List[Optional["GetTeamScoringGetTeamScoringAthleteDetail"]]]
    first_name: Optional[str] = Field(alias="firstName")
    last_name: Optional[str] = Field(alias="lastName")
    birth_date: Optional[Any] = Field(alias="birthDate")
    birth_place: Optional[str] = Field(alias="birthPlace")
    birth_country_code: Optional[str] = Field(alias="birthCountryCode")
    birth_place_country_name: Optional[str] = Field(alias="birthPlaceCountryName")
    team_name: Optional[str] = Field(alias="teamName")
    country_name: Optional[str] = Field(alias="countryName")
    country_code: Optional[str] = Field(alias="countryCode")
    sex_code: Optional[str] = Field(alias="sexCode")
    sex_name: Optional[str] = Field(alias="sexName")


class GetTeamScoringGetTeamScoringAthleteDetail(BaseModel):
    id: Optional[int]
    updated_on: Optional[Any] = Field(alias="updatedOn")
    hash: Optional[str]
    type_code: Optional[str] = Field(alias="typeCode")
    first_name: Optional[str] = Field(alias="firstName")
    last_name: Optional[str] = Field(alias="lastName")
    sex_code: Optional[str] = Field(alias="sexCode")
    sex_name: Optional[str] = Field(alias="sexName")
    country_code: Optional[str] = Field(alias="countryCode")
    country_name: Optional[str] = Field(alias="countryName")
    birth_date_str: Optional[str] = Field(alias="birthDateStr")
    url_slug: Optional[str] = Field(alias="urlSlug")
    representative_id: Optional[int] = Field(alias="representativeId")
    name: Optional[str]
    country_url_slug: Optional[str] = Field(alias="countryUrlSlug")
    sex_name_url_slug: Optional[str] = Field(alias="sexNameUrlSlug")
    friendly_name: Optional[str] = Field(alias="friendlyName")
    friendly_name_letter: Optional[str] = Field(alias="friendlyNameLetter")
    friendly_name_first3_letter: Optional[str] = Field(alias="friendlyNameFirst3Letter")


GetTeamScoring.update_forward_refs()
GetTeamScoringGetTeamScoring.update_forward_refs()
GetTeamScoringGetTeamScoringAthlete.update_forward_refs()
GetTeamScoringGetTeamScoringAthleteDetail.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:50
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetFilterTypes(BaseModel):
    get_filter_types: Optional[List[Optional["GetFilterTypesGetFilterTypes"]]] = Field(
        alias="getFilterTypes"
    )


class GetFilterTypesGetFilterTypes(BaseModel):
    id: Optional[str]
    content_id: Optional[str] = Field(alias="contentId")
    published: Optional[Any]
    published_by_id: Optional[str] = Field(alias="publishedById")
    published_by_name: Optional[str] = Field(alias="publishedByName")
    filters: Optional[List[Optional["GetFilterTypesGetFilterTypesFilters"]]]
    language: Optional[str]
    title: Optional[str]
    slug: Optional[str]
    type_id: Optional[str] = Field(alias="typeId")
    site_id: Optional[str] = Field(alias="siteId")


class GetFilterTypesGetFilterTypesFilters(BaseModel):
    id: Optional[str]
    content_id: Optional[str] = Field(alias="contentId")
    type_id: Optional[str] = Field(alias="typeId")
    type: Optional["GetFilterTypesGetFilterTypesFiltersType"]
    published: Optional[Any]
    published_by_id: Optional[str] = Field(alias="publishedById")
    published_by_name: Optional[str] = Field(alias="publishedByName")
    language: Optional[str]
    title: Optional[str]
    slug: Optional[str]


class GetFilterTypesGetFilterTypesFiltersType(BaseModel):
    id: Optional[str]
    content_id: Optional[str] = Field(alias="contentId")
    published: Optional[Any]
    published_by_id: Optional[str] = Field(alias="publishedById")
    published_by_name: Optional[str] = Field(alias="publishedByName")
    filters: Optional[List[Optional["GetFilterTypesGetFilterTypesFiltersTypeFilters"]]]
    language: Optional[str]
    title: Optional[str]
    slug: Optional[str]
    type_id: Optional[str] = Field(alias="typeId")
    site_id: Optional[str] = Field(alias="siteId")


class GetFilterTypesGetFilterTypesFiltersTypeFilters(BaseModel):
    id: Optional[str]
    content_id: Optional[str] = Field(alias="contentId")
    type_id: Optional[str] = Field(alias="typeId")
    published: Optional[Any]
    published_by_id: Optional[str] = Field(alias="publishedById")
    published_by_name: Optional[str] = Field(alias="publishedByName")
    language: Optional[str]
    title: Optional[str]
    slug: Optional[str]


GetFilterTypes.update_forward_refs()
GetFilterTypesGetFilterTypes.update_forward_refs()
GetFilterTypesGetFilterTypesFilters.update_forward_refs()
GetFilterTypesGetFilterTypesFiltersType.update_forward_refs()
GetFilterTypesGetFilterTypesFiltersTypeFilters.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:50
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetRankingScoreCalculation(BaseModel):
    get_ranking_score_calculation: Optional[
        "GetRankingScoreCalculationGetRankingScoreCalculation"
    ] = Field(alias="getRankingScoreCalculation")


class GetRankingScoreCalculationGetRankingScoreCalculation(BaseModel):
    rank_date: Optional[str] = Field(alias="rankDate")
    event_group: Optional[str] = Field(alias="eventGroup")
    male: Optional[bool]
    athlete: Optional[str]
    athlete_url_slug: Optional[str] = Field(alias="athleteUrlSlug")
    birth_date: Optional[str] = Field(alias="birthDate")
    country: Optional[str]
    country_full_name: Optional[str] = Field(alias="countryFullName")
    place: Optional[int]
    with_wind: Optional[bool] = Field(alias="withWind")
    with_drop: Optional[bool] = Field(alias="withDrop")
    with_world_record: Optional[bool] = Field(alias="withWorldRecord")
    with_month_correction: Optional[bool] = Field(alias="withMonthCorrection")
    average_performance_score: Optional[int] = Field(alias="averagePerformanceScore")
    ranking_score: Optional[int] = Field(alias="rankingScore")
    results: Optional[
        List[Optional["GetRankingScoreCalculationGetRankingScoreCalculationResults"]]
    ]


class GetRankingScoreCalculationGetRankingScoreCalculationResults(BaseModel):
    date: Optional[str]
    competition: Optional[str]
    country: Optional[str]
    category: Optional[str]
    discipline_code: Optional[str] = Field(alias="disciplineCode")
    discipline_name_url_slug: Optional[str] = Field(alias="disciplineNameUrlSlug")
    type_name_url_slug: Optional[str] = Field(alias="typeNameUrlSlug")
    indoor: Optional[bool]
    discipline: Optional[str]
    race: Optional[str]
    place: Optional[str]
    mark: Optional[str]
    wind: Optional[str]
    drop: Optional[str]
    result_score: Optional[int] = Field(alias="resultScore")
    world_record: Optional[int] = Field(alias="worldRecord")
    placing_score: Optional[int] = Field(alias="placingScore")
    performance_score: Optional[int] = Field(alias="performanceScore")
    month_correction_applied: Optional[bool] = Field(alias="monthCorrectionApplied")


GetRankingScoreCalculation.update_forward_refs()
GetRankingScoreCalculationGetRankingScoreCalculation.update_forward_refs()
GetRankingScoreCalculationGetRankingScoreCalculationResults.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetMedalDetails(BaseModel):
    get_medal_details: Optional[
        List[Optional["GetMedalDetailsGetMedalDetails"]]
    ] = Field(alias="getMedalDetails")


class GetMedalDetailsGetMedalDetails(BaseModel):
    id: Optional[int]
    medal_table_id: Optional[int] = Field(alias="medalTableId")
    type_id: Optional[int] = Field(alias="typeId")
    discipline_code: Optional[str] = Field(alias="disciplineCode")
    discipline_name: Optional[str] = Field(alias="disciplineName")
    sex_code: Optional[str] = Field(alias="sexCode")
    result_id: Optional[int] = Field(alias="resultId")
    result_mark: Optional[str] = Field(alias="resultMark")
    medal_date: Optional[str] = Field(alias="medalDate")
    details_order: Optional[int] = Field(alias="detailsOrder")
    competitor_id: Optional[int] = Field(alias="competitorId")
    competitor_first_name: Optional[str] = Field(alias="competitorFirstName")
    competitor_last_name: Optional[str] = Field(alias="competitorLastName")
    event_id: Optional[int] = Field(alias="eventId")
    phase_id: Optional[int] = Field(alias="phaseId")
    updated_on: Optional[str] = Field(alias="updatedOn")
    event_store_id: Optional[str] = Field(alias="eventStoreId")


GetMedalDetails.update_forward_refs()
GetMedalDetailsGetMedalDetails.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class GetCompetitorAAId(BaseModel):
    get_competitor_a_a_id: Optional[int] = Field(alias="getCompetitorAAId")


GetCompetitorAAId.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetCISCompetitorResDisp(BaseModel):
    get_c_i_s_competitor_res_disp: Optional[
        "GetCISCompetitorResDispGetCISCompetitorResDisp"
    ] = Field(alias="getCISCompetitorResDisp")


class GetCISCompetitorResDispGetCISCompetitorResDisp(BaseModel):
    parameters: Optional["GetCISCompetitorResDispGetCISCompetitorResDispParameters"]
    active_years: Optional[List[Optional[str]]] = Field(alias="activeYears")
    results_by_event: Optional[
        List[Optional["GetCISCompetitorResDispGetCISCompetitorResDispResultsByEvent"]]
    ] = Field(alias="resultsByEvent")
    results_by_date: Optional[
        List[Optional["GetCISCompetitorResDispGetCISCompetitorResDispResultsByDate"]]
    ] = Field(alias="resultsByDate")


class GetCISCompetitorResDispGetCISCompetitorResDispParameters(BaseModel):
    results_by_year: Optional[int] = Field(alias="resultsByYear")
    results_by_year_order_by: Optional[str] = Field(alias="resultsByYearOrderBy")


class GetCISCompetitorResDispGetCISCompetitorResDispResultsByEvent(BaseModel):
    indoor: Optional[bool]
    discipline_code: Optional[str] = Field(alias="disciplineCode")
    discipline_name_url_slug: Optional[str] = Field(alias="disciplineNameUrlSlug")
    type_name_url_slug: Optional[str] = Field(alias="typeNameUrlSlug")
    discipline: Optional[str]
    with_wind: Optional[bool] = Field(alias="withWind")
    with_remark: Optional[bool] = Field(alias="withRemark")
    results: Optional[
        List[
            Optional[
                "GetCISCompetitorResDispGetCISCompetitorResDispResultsByEventResults"
            ]
        ]
    ]


class GetCISCompetitorResDispGetCISCompetitorResDispResultsByEventResults(BaseModel):
    date: Optional[str]
    competition: Optional[str]
    venue: Optional[str]
    indoor: Optional[bool]
    country: Optional[str]
    category: Optional[str]
    race: Optional[str]
    place: Optional[str]
    mark: Optional[str]
    wind: Optional[str]
    not_legal: Optional[bool] = Field(alias="notLegal")
    result_score: Optional[int] = Field(alias="resultScore")
    remark: Optional[str]


class GetCISCompetitorResDispGetCISCompetitorResDispResultsByDate(BaseModel):
    date: Optional[str]
    competition: Optional[str]
    venue: Optional[str]
    indoor: Optional[bool]
    country: Optional[str]
    category: Optional[str]
    race: Optional[str]
    place: Optional[str]
    mark: Optional[str]
    wind: Optional[str]
    not_legal: Optional[bool] = Field(alias="notLegal")
    result_score: Optional[int] = Field(alias="resultScore")
    remark: Optional[str]


GetCISCompetitorResDisp.update_forward_refs()
GetCISCompetitorResDispGetCISCompetitorResDisp.update_forward_refs()
GetCISCompetitorResDispGetCISCompetitorResDispParameters.update_forward_refs()
GetCISCompetitorResDispGetCISCompetitorResDispResultsByEvent.update_forward_refs()
GetCISCompetitorResDispGetCISCompetitorResDispResultsByEventResults.update_forward_refs()
GetCISCompetitorResDispGetCISCompetitorResDispResultsByDate.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetAllTimeList(BaseModel):
    get_all_time_list: Optional["GetAllTimeListGetAllTimeList"] = Field(
        alias="getAllTimeList"
    )


class GetAllTimeListGetAllTimeList(BaseModel):
    page: Optional[int]
    pages: Optional[int]
    payload: Optional[List[Optional["GetAllTimeListGetAllTimeListPayload"]]]


class GetAllTimeListGetAllTimeListPayload(BaseModel):
    position: Optional[int]
    place: Optional[str]
    achiever_position: Optional[int] = Field(alias="achieverPosition")
    result: Optional[str]
    achiever: Optional[str]
    nationality: Optional[str]
    venue: Optional[str]
    date: Optional[str]
    result_score: Optional[int] = Field(alias="resultScore")


GetAllTimeList.update_forward_refs()
GetAllTimeListGetAllTimeList.update_forward_refs()
GetAllTimeListGetAllTimeListPayload.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetEventTeamStandings(BaseModel):
    get_event_team_standings: Optional[
        List[Optional["GetEventTeamStandingsGetEventTeamStandings"]]
    ] = Field(alias="getEventTeamStandings")


class GetEventTeamStandingsGetEventTeamStandings(BaseModel):
    id: Optional[int]
    updated_on: Optional[Any] = Field(alias="updatedOn")
    hash: Optional[str]
    event_id: Optional[int] = Field(alias="eventId")
    rank: Optional[int]
    team_name: Optional[str] = Field(alias="teamName")
    team_country_code: Optional[str] = Field(alias="teamCountryCode")
    team_id: Optional[int] = Field(alias="teamId")
    team_id__w_a: Optional[int] = Field(alias="teamId_WA")
    event_id__w_a: Optional[int] = Field(alias="eventId_WA")
    event_sub_category_code: Optional[str] = Field(alias="eventSubCategoryCode")
    sex_code: Optional[str] = Field(alias="sexCode")
    sex_name: Optional[str] = Field(alias="sexName")
    standing_mark: Optional[str] = Field(alias="standingMark")
    event_team_standing_order: Optional[int] = Field(alias="eventTeamStandingOrder")


GetEventTeamStandings.update_forward_refs()
GetEventTeamStandingsGetEventTeamStandings.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetEventLeadingStandings(BaseModel):
    get_event_leading_standings: Optional[
        List[Optional["GetEventLeadingStandingsGetEventLeadingStandings"]]
    ] = Field(alias="getEventLeadingStandings")


class GetEventLeadingStandingsGetEventLeadingStandings(BaseModel):
    event_circuit_code: Optional[str] = Field(alias="eventCircuitCode")
    sex_code: Optional[str] = Field(alias="sexCode")
    season: Optional[int]
    event_circuit_type_code: Optional[str] = Field(alias="eventCircuitTypeCode")
    rank: Optional[str]
    competitor_id: Optional[int] = Field(alias="competitorId")
    competitor_id__w_a: Optional[int] = Field(alias="competitorId_WA")
    competitor_name: Optional[str] = Field(alias="competitorName")
    competitor_country_code: Optional[str] = Field(alias="competitorCountryCode")
    total_results: Optional[int] = Field(alias="totalResults")
    total_points: Optional[str] = Field(alias="totalPoints")
    event_circuit_standing_order: Optional[int] = Field(
        alias="eventCircuitStandingOrder"
    )
    discipline: Optional["GetEventLeadingStandingsGetEventLeadingStandingsDiscipline"]


class GetEventLeadingStandingsGetEventLeadingStandingsDiscipline(BaseModel):
    name: Optional[str]


GetEventLeadingStandings.update_forward_refs()
GetEventLeadingStandingsGetEventLeadingStandings.update_forward_refs()
GetEventLeadingStandingsGetEventLeadingStandingsDiscipline.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:50
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetMetaData(BaseModel):
    get_meta_data: Optional["GetMetaDataGetMetaData"] = Field(alias="getMetaData")


class GetMetaDataGetMetaData(BaseModel):
    country_codes: Optional[
        List[Optional["GetMetaDataGetMetaDataCountryCodes"]]
    ] = Field(alias="countryCodes")
    discipline_codes: Optional[
        List[Optional["GetMetaDataGetMetaDataDisciplineCodes"]]
    ] = Field(alias="disciplineCodes")


class GetMetaDataGetMetaDataCountryCodes(BaseModel):
    code: Optional[str]
    name: Optional[str]


class GetMetaDataGetMetaDataDisciplineCodes(BaseModel):
    code: Optional[str]
    name: Optional[str]


GetMetaData.update_forward_refs()
GetMetaDataGetMetaData.update_forward_refs()
GetMetaDataGetMetaDataCountryCodes.update_forward_refs()
GetMetaDataGetMetaDataDisciplineCodes.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetMedal(BaseModel):
    get_medal: Optional[List[Optional["GetMedalGetMedal"]]] = Field(alias="getMedal")


class GetMedalGetMedal(BaseModel):
    id: int
    event_id: int = Field(alias="eventId")
    country_code: Optional[str] = Field(alias="countryCode")
    country_name: Optional[str] = Field(alias="countryName")
    event_medal_table_order: Optional[int] = Field(alias="eventMedalTableOrder")
    event_sub_category_code: Optional[str] = Field(alias="eventSubCategoryCode")
    medal_rank: Optional[int] = Field(alias="medalRank")
    bronze: Optional[int]
    silver: Optional[int]
    gold: Optional[int]
    total: Optional[int]
    updated_on: Optional[str] = Field(alias="updatedOn")
    event_store_id: Optional[str] = Field(alias="eventStoreId")


GetMedal.update_forward_refs()
GetMedalGetMedal.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:50
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetResultInfo(BaseModel):
    get_result_info: Optional[List[Optional["GetResultInfoGetResultInfo"]]] = Field(
        alias="getResultInfo"
    )


class GetResultInfoGetResultInfo(BaseModel):
    id: Optional[str]
    title: Optional[str]
    file_name: Optional[str] = Field(alias="fileName")
    info_type: Optional[int] = Field(alias="infoType")
    event_id: Optional[int] = Field(alias="eventId")
    competition_id: Optional[str] = Field(alias="competitionId")


GetResultInfo.update_forward_refs()
GetResultInfoGetResultInfo.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:50
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetRandomWorldRankingDiscipline(BaseModel):
    get_random_world_ranking_discipline: Optional[
        List[Optional["GetRandomWorldRankingDisciplineGetRandomWorldRankingDiscipline"]]
    ] = Field(alias="getRandomWorldRankingDiscipline")


class GetRandomWorldRankingDisciplineGetRandomWorldRankingDiscipline(BaseModel):
    name: Optional[str]
    display_name: Optional[str] = Field(alias="displayName")
    gender: Optional[str]
    url_slug: Optional[str] = Field(alias="urlSlug")
    discipline_codes: Optional[List[Optional[str]]] = Field(alias="disciplineCodes")
    rankings: Optional[
        List[
            Optional[
                "GetRandomWorldRankingDisciplineGetRandomWorldRankingDisciplineRankings"
            ]
        ]
    ]
    query: Optional[
        "GetRandomWorldRankingDisciplineGetRandomWorldRankingDisciplineQuery"
    ]


class GetRandomWorldRankingDisciplineGetRandomWorldRankingDisciplineRankings(BaseModel):
    id: int
    place: Optional[int]
    competitor_name: Optional[str] = Field(alias="competitorName")
    competitor_country_url_slug: Optional[str] = Field(alias="competitorCountryUrlSlug")
    competitor_url_slug: Optional[str] = Field(alias="competitorUrlSlug")
    competitor_birth_date: Optional[Any] = Field(alias="competitorBirthDate")
    country_code: Optional[str] = Field(alias="countryCode")
    ranking_score: Optional[int] = Field(alias="rankingScore")
    discipline_codes: Optional[List[Optional[str]]] = Field(alias="disciplineCodes")
    country_place: Optional[int] = Field(alias="countryPlace")
    previous_id: Optional[int] = Field(alias="previousId")
    previous_place: Optional[int] = Field(alias="previousPlace")
    previous_ranking_score: Optional[int] = Field(alias="previousRankingScore")


class GetRandomWorldRankingDisciplineGetRandomWorldRankingDisciplineQuery(BaseModel):
    limit: Optional[int]
    gender: Optional[str]
    event_group: Optional[str] = Field(alias="eventGroup")


GetRandomWorldRankingDiscipline.update_forward_refs()
GetRandomWorldRankingDisciplineGetRandomWorldRankingDiscipline.update_forward_refs()
GetRandomWorldRankingDisciplineGetRandomWorldRankingDisciplineRankings.update_forward_refs()
GetRandomWorldRankingDisciplineGetRandomWorldRankingDisciplineQuery.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetWawCompetitionEventsOrganizerDetails(BaseModel):
    get_waw_competition_events_organizer_details: Optional[
        List[
            Optional[
                "GetWawCompetitionEventsOrganizerDetailsGetWawCompetitionEventsOrganizerDetails"
            ]
        ]
    ] = Field(alias="getWawCompetitionEventsOrganizerDetails")


class GetWawCompetitionEventsOrganizerDetailsGetWawCompetitionEventsOrganizerDetails(
    BaseModel
):
    id: Optional[int]
    event_id__w_a: Optional[int] = Field(alias="eventId_WA")
    name: Optional[str]
    start_date: Optional[Any] = Field(alias="startDate")
    venue: Optional[str]
    country_code: Optional[str] = Field(alias="countryCode")
    organizer_details: Optional[
        List[
            Optional[
                "GetWawCompetitionEventsOrganizerDetailsGetWawCompetitionEventsOrganizerDetailsOrganizerDetails"
            ]
        ]
    ] = Field(alias="organizerDetails")


class GetWawCompetitionEventsOrganizerDetailsGetWawCompetitionEventsOrganizerDetailsOrganizerDetails(
    BaseModel
):
    name: Optional[str]
    value: Optional[str]


GetWawCompetitionEventsOrganizerDetails.update_forward_refs()
GetWawCompetitionEventsOrganizerDetailsGetWawCompetitionEventsOrganizerDetails.update_forward_refs()
GetWawCompetitionEventsOrganizerDetailsGetWawCompetitionEventsOrganizerDetailsOrganizerDetails.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class TeamStandings(BaseModel):
    team_standings: Optional[List[Optional["TeamStandingsTeamStandings"]]] = Field(
        alias="teamStandings"
    )


class TeamStandingsTeamStandings(BaseModel):
    id: Optional[int]
    phase_id: Optional[int] = Field(alias="phaseId")
    unit_id: Optional[int] = Field(alias="unitId")
    type: Optional[str]
    competition_intermediate_id: Optional[int] = Field(
        alias="competitionIntermediateId"
    )
    competition_intermediate_name: Optional[str] = Field(
        alias="competitionIntermediateName"
    )
    rank: Optional[int]
    team_id: Optional[int] = Field(alias="teamId")
    team_id__w_a: Optional[int] = Field(alias="teamId_WA")
    team_name: Optional[str] = Field(alias="teamName")
    team_country_code: Optional[str] = Field(alias="teamCountryCode")
    standing_mark: Optional[str] = Field(alias="standingMark")
    live_current: Optional[bool] = Field(alias="liveCurrent")
    updated_on: Optional[Any] = Field(alias="updatedOn")
    team_standing_id: Optional[int] = Field(alias="teamStandingId")
    competition_intermediate_order: Optional[int] = Field(
        alias="competitionIntermediateOrder"
    )
    detail_rank: Optional[int] = Field(alias="detailRank")
    standing_detail_bib: Optional[str] = Field(alias="standingDetailBib")
    competitor_id: Optional[List[Optional[int]]] = Field(alias="competitorId")
    related_athlete: Optional[
        List[Optional["TeamStandingsTeamStandingsRelatedAthlete"]]
    ] = Field(alias="relatedAthlete")
    standing_detail_score: Optional[str] = Field(alias="standingDetailScore")
    standing_detail_scoring: Optional[str] = Field(alias="standingDetailScoring")
    team_standing_order: Optional[int] = Field(alias="teamStandingOrder")
    team_standing_detail_order: Optional[int] = Field(alias="teamStandingDetailOrder")
    event_store_id: Optional[str] = Field(alias="eventStoreId")
    chunk_order: Optional[int] = Field(alias="chunkOrder")
    chunk_id: Optional[str] = Field(alias="chunkId")


class TeamStandingsTeamStandingsRelatedAthlete(BaseModel):
    competitor_id: Optional[List[Optional[int]]] = Field(alias="competitorId")
    detail: Optional[List[Optional["TeamStandingsTeamStandingsRelatedAthleteDetail"]]]
    first_name: Optional[str] = Field(alias="firstName")
    last_name: Optional[str] = Field(alias="lastName")
    birth_date: Optional[Any] = Field(alias="birthDate")
    birth_place: Optional[str] = Field(alias="birthPlace")
    birth_country_code: Optional[str] = Field(alias="birthCountryCode")
    birth_place_country_name: Optional[str] = Field(alias="birthPlaceCountryName")
    team_name: Optional[str] = Field(alias="teamName")
    country_name: Optional[str] = Field(alias="countryName")
    country_code: Optional[str] = Field(alias="countryCode")
    sex_code: Optional[str] = Field(alias="sexCode")
    sex_name: Optional[str] = Field(alias="sexName")


class TeamStandingsTeamStandingsRelatedAthleteDetail(BaseModel):
    id: Optional[int]
    updated_on: Optional[Any] = Field(alias="updatedOn")
    hash: Optional[str]
    type_code: Optional[str] = Field(alias="typeCode")
    first_name: Optional[str] = Field(alias="firstName")
    last_name: Optional[str] = Field(alias="lastName")
    sex_code: Optional[str] = Field(alias="sexCode")
    sex_name: Optional[str] = Field(alias="sexName")
    country_code: Optional[str] = Field(alias="countryCode")
    country_name: Optional[str] = Field(alias="countryName")
    birth_date_str: Optional[str] = Field(alias="birthDateStr")
    url_slug: Optional[str] = Field(alias="urlSlug")
    representative_id: Optional[int] = Field(alias="representativeId")
    name: Optional[str]
    country_url_slug: Optional[str] = Field(alias="countryUrlSlug")
    sex_name_url_slug: Optional[str] = Field(alias="sexNameUrlSlug")
    friendly_name: Optional[str] = Field(alias="friendlyName")
    friendly_name_letter: Optional[str] = Field(alias="friendlyNameLetter")
    friendly_name_first3_letter: Optional[str] = Field(alias="friendlyNameFirst3Letter")


TeamStandings.update_forward_refs()
TeamStandingsTeamStandings.update_forward_refs()
TeamStandingsTeamStandingsRelatedAthlete.update_forward_refs()
TeamStandingsTeamStandingsRelatedAthleteDetail.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetCampaigns(BaseModel):
    get_campaigns: Optional[List[Optional["GetCampaignsGetCampaigns"]]] = Field(
        alias="getCampaigns"
    )


class GetCampaignsGetCampaigns(BaseModel):
    id: Optional[str]
    value: Optional[str]
    key: Optional[str]
    type: Optional[str]
    description: Optional[str]
    thank_you_message: Optional[str] = Field(alias="thankYouMessage")
    already_signed_message: Optional[str] = Field(alias="alreadySignedMessage")
    close_date: Optional[Any] = Field(alias="closeDate")
    redirect_url: Optional[str] = Field(alias="redirectUrl")
    tag_user_friendly_name: Optional[str] = Field(alias="tagUserFriendlyName")
    deleted: Optional[bool]
    visible_on_preference_center: Optional[bool] = Field(
        alias="visibleOnPreferenceCenter"
    )
    short_form: Optional[bool] = Field(alias="shortForm")
    top_level_bucket_id: Optional[str] = Field(alias="topLevelBucketId")


GetCampaigns.update_forward_refs()
GetCampaignsGetCampaigns.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetLatestRecords(BaseModel):
    get_latest_records: Optional["GetLatestRecordsGetLatestRecords"] = Field(
        alias="getLatestRecords"
    )


class GetLatestRecordsGetLatestRecords(BaseModel):
    module_title: Optional[str] = Field(alias="moduleTitle")
    module_subtitle: Optional[str] = Field(alias="moduleSubtitle")
    records: Optional[List[Optional["GetLatestRecordsGetLatestRecordsRecords"]]]


class GetLatestRecordsGetLatestRecordsRecords(BaseModel):
    record_type: Optional[str] = Field(alias="recordType")
    mark: Optional[str]
    event_name: Optional[str] = Field(alias="eventName")
    competitor: Optional["GetLatestRecordsGetLatestRecordsRecordsCompetitor"]
    date: Optional[Any]
    location: Optional[str]
    country_name: Optional[str] = Field(alias="countryName")


class GetLatestRecordsGetLatestRecordsRecordsCompetitor(BaseModel):
    name: Optional[str]
    id: Optional[int]
    url_slug: Optional[str] = Field(alias="urlSlug")
    country_url_slug: Optional[str] = Field(alias="countryUrlSlug")
    birth_date: Optional[Any] = Field(alias="birthDate")
    team_members: Optional[
        List[Optional["GetLatestRecordsGetLatestRecordsRecordsCompetitorTeamMembers"]]
    ] = Field(alias="teamMembers")


class GetLatestRecordsGetLatestRecordsRecordsCompetitorTeamMembers(BaseModel):
    id: Optional[int]
    name: Optional[str]
    iaaf_id: Optional[int] = Field(alias="iaafId")
    url_slug: Optional[str] = Field(alias="urlSlug")


GetLatestRecords.update_forward_refs()
GetLatestRecordsGetLatestRecords.update_forward_refs()
GetLatestRecordsGetLatestRecordsRecords.update_forward_refs()
GetLatestRecordsGetLatestRecordsRecordsCompetitor.update_forward_refs()
GetLatestRecordsGetLatestRecordsRecordsCompetitorTeamMembers.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetAthleteRepresentativeProfile(BaseModel):
    get_athlete_representative_profile: Optional[
        "GetAthleteRepresentativeProfileGetAthleteRepresentativeProfile"
    ] = Field(alias="getAthleteRepresentativeProfile")


class GetAthleteRepresentativeProfileGetAthleteRepresentativeProfile(BaseModel):
    athlete_representative_id: Optional[int] = Field(alias="athleteRepresentativeId")
    country_code: Optional[str] = Field(alias="countryCode")
    instagram: Optional[List[Optional[str]]]
    telephone: Optional[List[Optional[str]]]
    facebook: Optional[List[Optional[str]]]
    twitter: Optional[List[Optional[str]]]
    website: Optional[List[Optional[str]]]
    youtube: Optional[List[Optional[str]]]
    first_name: Optional[str] = Field(alias="firstName")
    mobile: Optional[List[Optional[str]]]
    last_name: Optional[str] = Field(alias="lastName")
    toplist: Optional[
        "GetAthleteRepresentativeProfileGetAthleteRepresentativeProfileToplist"
    ]
    country: Optional[str]
    email: Optional[List[Optional[str]]]


class GetAthleteRepresentativeProfileGetAthleteRepresentativeProfileToplist(BaseModel):
    athletes: Optional[
        List[
            Optional[
                "GetAthleteRepresentativeProfileGetAthleteRepresentativeProfileToplistAthletes"
            ]
        ]
    ]
    toplist_date: Optional[str] = Field(alias="toplistDate")


class GetAthleteRepresentativeProfileGetAthleteRepresentativeProfileToplistAthletes(
    BaseModel
):
    athlete_representative_id: Optional[int] = Field(alias="athleteRepresentativeId")
    country_code: Optional[str] = Field(alias="countryCode")
    first_name: Optional[str] = Field(alias="firstName")
    birthdate: Optional[str]
    athlete_id: Optional[int] = Field(alias="athleteId")
    last_name: Optional[str] = Field(alias="lastName")
    country: Optional[str]
    gender: Optional[str]


GetAthleteRepresentativeProfile.update_forward_refs()
GetAthleteRepresentativeProfileGetAthleteRepresentativeProfile.update_forward_refs()
GetAthleteRepresentativeProfileGetAthleteRepresentativeProfileToplist.update_forward_refs()
GetAthleteRepresentativeProfileGetAthleteRepresentativeProfileToplistAthletes.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class CompetitionDocument(BaseModel):
    competition_document: Optional[
        List[Optional["CompetitionDocumentCompetitionDocument"]]
    ] = Field(alias="competitionDocument")


class CompetitionDocumentCompetitionDocument(BaseModel):
    event_id: Optional[int] = Field(alias="eventId")
    event_id__w_a: Optional[int] = Field(alias="eventId_WA")
    file_name: Optional[str] = Field(alias="fileName")
    file_path: Optional[str] = Field(alias="filePath")
    hash: Optional[str]
    id: Optional[int]
    phase_id: Optional[int] = Field(alias="phaseId")
    type_id: Optional[int] = Field(alias="typeId")
    type_name: Optional[str] = Field(alias="typeName")
    type_order: Optional[int] = Field(alias="typeOrder")
    unit_id: Optional[int] = Field(alias="unitId")
    updated_on: Optional[Any] = Field(alias="updatedOn")


CompetitionDocument.update_forward_refs()
CompetitionDocumentCompetitionDocument.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:50
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetWorldLeadingCompetitors(BaseModel):
    get_world_leading_competitors: Optional[
        "GetWorldLeadingCompetitorsGetWorldLeadingCompetitors"
    ] = Field(alias="getWorldLeadingCompetitors")


class GetWorldLeadingCompetitorsGetWorldLeadingCompetitors(BaseModel):
    module_title: Optional[str] = Field(alias="moduleTitle")
    module_subtitle: Optional[str] = Field(alias="moduleSubtitle")
    event_results: Optional[
        List[
            Optional["GetWorldLeadingCompetitorsGetWorldLeadingCompetitorsEventResults"]
        ]
    ] = Field(alias="eventResults")


class GetWorldLeadingCompetitorsGetWorldLeadingCompetitorsEventResults(BaseModel):
    event_name: Optional[str] = Field(alias="eventName")
    environment: Optional[str]
    age_category: Optional[str] = Field(alias="ageCategory")
    season: Optional[int]
    discipline_url_slug: Optional[str] = Field(alias="disciplineUrlSlug")
    discipline_type_url_slug: Optional[str] = Field(alias="disciplineTypeUrlSlug")
    sex_code: Optional[str] = Field(alias="sexCode")
    results: Optional[
        List[
            Optional[
                "GetWorldLeadingCompetitorsGetWorldLeadingCompetitorsEventResultsResults"
            ]
        ]
    ]


class GetWorldLeadingCompetitorsGetWorldLeadingCompetitorsEventResultsResults(
    BaseModel
):
    mark: Optional[str]
    country_code: Optional[str] = Field(alias="countryCode")
    competitor: Optional[
        "GetWorldLeadingCompetitorsGetWorldLeadingCompetitorsEventResultsResultsCompetitor"
    ]
    primary_media_id: Optional[List[Optional[str]]] = Field(alias="primaryMediaId")
    primary_media: Optional[
        List[
            Optional[
                "GetWorldLeadingCompetitorsGetWorldLeadingCompetitorsEventResultsResultsPrimaryMedia"
            ]
        ]
    ] = Field(alias="primaryMedia")


class GetWorldLeadingCompetitorsGetWorldLeadingCompetitorsEventResultsResultsCompetitor(
    BaseModel
):
    name: Optional[str]
    id: Optional[int]
    url_slug: Optional[str] = Field(alias="urlSlug")
    country_url_slug: Optional[str] = Field(alias="countryUrlSlug")
    birth_date: Optional[Any] = Field(alias="birthDate")


class GetWorldLeadingCompetitorsGetWorldLeadingCompetitorsEventResultsResultsPrimaryMedia(
    BaseModel
):
    id: Optional[str]
    title: Optional[str]
    s_e_o_title: Optional[str] = Field(alias="sEOTitle")
    url_slug: Optional[str] = Field(alias="urlSlug")
    credit: Optional[str]
    show_in_media: Optional[bool] = Field(alias="showInMedia")
    complete: Optional[bool]
    file_name: Optional[str] = Field(alias="fileName")
    remote_item_code: Optional[str] = Field(alias="remoteItemCode")
    x_m_l_file_name360: Optional[str] = Field(alias="xMLFileName360")
    file_name_url: Optional[str] = Field(alias="fileNameUrl")
    type: Optional[int]
    format: Optional[int]
    hosting: Optional[int]
    related_links: Optional[List[Optional[str]]] = Field(alias="relatedLinks")
    source_width: Optional[int] = Field(alias="sourceWidth")
    source_height: Optional[int] = Field(alias="sourceHeight")
    available_ratios: Optional[List[Optional[int]]] = Field(alias="availableRatios")
    related_sex_codes: Optional[List[Optional[int]]] = Field(alias="relatedSexCodes")
    related_age_groups: Optional[List[Optional[int]]] = Field(alias="relatedAgeGroups")
    related_event_phases: Optional[List[Optional[int]]] = Field(
        alias="relatedEventPhases"
    )
    status: Optional[int]
    live_from: Optional[Any] = Field(alias="liveFrom")
    created_on: Optional[str] = Field(alias="createdOn")
    updated_on: Optional[Any] = Field(alias="updatedOn")
    created_by_id: Optional[str] = Field(alias="createdById")
    updated_by_id: Optional[str] = Field(alias="updatedById")


GetWorldLeadingCompetitors.update_forward_refs()
GetWorldLeadingCompetitorsGetWorldLeadingCompetitors.update_forward_refs()
GetWorldLeadingCompetitorsGetWorldLeadingCompetitorsEventResults.update_forward_refs()
GetWorldLeadingCompetitorsGetWorldLeadingCompetitorsEventResultsResults.update_forward_refs()
GetWorldLeadingCompetitorsGetWorldLeadingCompetitorsEventResultsResultsCompetitor.update_forward_refs()
GetWorldLeadingCompetitorsGetWorldLeadingCompetitorsEventResultsResultsPrimaryMedia.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetEventCircuitStandings(BaseModel):
    get_event_circuit_standings: Optional[
        "GetEventCircuitStandingsGetEventCircuitStandings"
    ] = Field(alias="getEventCircuitStandings")


class GetEventCircuitStandingsGetEventCircuitStandings(BaseModel):
    circuit_name: Optional[str] = Field(alias="circuitName")
    parameters: Optional["GetEventCircuitStandingsGetEventCircuitStandingsParameters"]
    seasons: Optional[List[Optional[str]]]
    standings: Optional[
        List[Optional["GetEventCircuitStandingsGetEventCircuitStandingsStandings"]]
    ]


class GetEventCircuitStandingsGetEventCircuitStandingsParameters(BaseModel):
    gender: Optional[str]
    season: Optional[str]


class GetEventCircuitStandingsGetEventCircuitStandingsStandings(BaseModel):
    disciplines: Optional[str]
    entries: Optional[
        List[
            Optional["GetEventCircuitStandingsGetEventCircuitStandingsStandingsEntries"]
        ]
    ]


class GetEventCircuitStandingsGetEventCircuitStandingsStandingsEntries(BaseModel):
    athlete_id: Optional[int] = Field(alias="athleteId")
    athlete: Optional[str]
    country: Optional[str]
    rank: Optional[int]
    points: Optional[str]
    results: Optional[
        List[
            Optional[
                "GetEventCircuitStandingsGetEventCircuitStandingsStandingsEntriesResults"
            ]
        ]
    ]


class GetEventCircuitStandingsGetEventCircuitStandingsStandingsEntriesResults(
    BaseModel
):
    discipline: Optional[str]
    points: Optional[str]
    result: Optional[str]
    venue: Optional[str]
    place: Optional[int]
    date: Optional[str]
    details: Optional[str]


GetEventCircuitStandings.update_forward_refs()
GetEventCircuitStandingsGetEventCircuitStandings.update_forward_refs()
GetEventCircuitStandingsGetEventCircuitStandingsParameters.update_forward_refs()
GetEventCircuitStandingsGetEventCircuitStandingsStandings.update_forward_refs()
GetEventCircuitStandingsGetEventCircuitStandingsStandingsEntries.update_forward_refs()
GetEventCircuitStandingsGetEventCircuitStandingsStandingsEntriesResults.update_forward_refs()
